#ifndef __MC_3DQTCAMERA_H__
#define __MC_3DQTCAMERA_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "MC_3DCamera.h"

#include <QVector3D>

class MC_3DQtCamera : public MC_3DCamera
{
protected:

    QMatrix4x4 m_viewMatrix;    /*!< View matrix to send to the renderer */

public:

    MC_3DQtCamera(const QVector3D& position, const QVector3D& direction, const QVector3D& up):MC_3DCamera(position,direction,up) {}
    virtual ~MC_3DQtCamera() {}

    virtual void apply();

    const QMatrix4x4& viewMatrix()const { return m_viewMatrix; }
};

/*! \class MC_3DQtCamera MC_3DQtCamera.h "3DRenderer/3DCamera/MC_3DQtCamera.h"
    \brief Qt implementation of the camera

    This camera creates a view QMatrix4x4 to use in the program (normaly through a QGLShaderProgram)
 */

/*! \fn MC_3DQtCamera :: MC_3DQtCamera(const QVector3D& position, const QVector3D& interestPoint, const QVector3D& up)
    \param position
    \param interestPoint
    \param up
 */

/*! \fn virtual MC_3DQtCamera :: ~MC_3DQtCamera()
 */

/*! \fn const QMatrix4x4& MC_3DQtCamera :: viewMatrix()const
    \return the view matrix from the camera
 */

#endif
