/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "MC_3DSatelliteCamera2.h"

#include "3DRenderer/MathUtils.h"

// Magic numbers for camera speed
#define ANGLE_STEP      0.2f
#define DISTANCE_STEP   0.02f

MC_3DSatelliteCamera2 :: MC_3DSatelliteCamera2(float distance)
    :MC_3DSatelliteCamera(distance),m_rotZ(0)
{

}

void MC_3DSatelliteCamera2 :: rotateAroundZ(int nbSteps)
{
    if ( nbSteps == 0 )
    {
        return;
    }

    m_rotZ += ANGLE_STEP * nbSteps;

    this->update();
}

void MC_3DSatelliteCamera2 :: apply()
{
    m_viewMatrix.setToIdentity();
    m_viewMatrix.lookAt(m_position,
                        m_interestPoint,
                        m_up);
    m_viewMatrix.rotate(m_rotZ,0,0,1);
}

QDebug operator<<(QDebug dbg, const MC_3DSatelliteCamera2& sc)
{
    dbg << "Distance: " << sc.distance() << " RotationX: " << sc.rotX() << " RotationY: " << sc.rotY() << " RotationZ: " << sc.rotZ();
    dbg << "\n";

    dbg << "Position: " << sc.position();
    dbg << "Direction: " << sc.interestPoint();
    dbg << "Up: " << sc.up();

    return dbg.space();
}
