#ifndef __MC_3DPARSERFACTORY_H__
#define __MC_3DPARSERFACTORY_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QMap>
#include <QString>

class QByteArray;

class MC_3DParser;
class MC_3DShapeModelList;

class MC_3DParserFactory
{
private:

    QMap< QString , MC_3DParser* > m_parsers;

public:

    ~MC_3DParserFactory();

    void registerParser(const QString& extension, MC_3DParser* pParser);

    bool parse(const QString& fileName, MC_3DShapeModelList& shapeList);
    bool parse(const QByteArray& data, const QString& dataType, MC_3DShapeModelList& shapeList, const QString& shapeName);

    QStringList getAvailableExtensions()const;
};

/*! \class MC_3DParserFactory MC_3DParserFactory.h 3DRenderer/3DParser/MC_3DParserFactory.h
    \brief Container for all parsers available

    The parsers can be registered using registerParser() and will be recognised by the parse() function.
    The parser function will call the correct parser depending on the extension of the file.
*/

/*! \fn MC_3DParserFactory::~MC_3DParserFactory();
 */

/*! \fn void MC_3DParserFactory::registerParser(const QString& extension, MC_3DParser* pParser);
    \brief Register the pParser in the factory
    \param extension the extension that will be associated with pParser.
    \param pParser the parser to register in the factory
    It is possible to pass an extension list where the separator is '|'.
    The QString will be decomposed and the parser will be registered for each members
 */

/*! \fn bool MC_3DParserFactory::parse(const QString& fileName, MC_3DShapeModelList& shapeList);
    \brief parse the file corresponding to 'fileName' and fill 'shapeList' with the data from the file
    \param fileName the name of the file to parse
    \param shapeList the list of shapes where to put the new shape
    \return true if the parse is done ; false if the file does not exist or the extension is not recognised
    The function checks if the file exist on the system.
    If the file exist, the extension (last characters after the last '.') are used to determine which parser to use.
 */

/*! \fn bool MC_3DParserFactory :: parse(const QByteArray& data, const QString& dataType, MC_3DShapeModelList& shapeList, const QString& shapeName)
    \brief parse 'data' and fill the 'shapeList' with the data
    \param data the data to parser
    \param dataType the type of the data
    \param shapeList the list to fill
    \param shapeName the name of the new shape
    \return true if the parse is done ; false if the data type is not known
 */

/*! \fn QStringList MC_3DParserFactory::getAvailableExtensions()const;
    \brief Go through the list of available parsers to get the extensions which can be parsed
    \return a QStringList containing the different extension possible to parse
*/

#endif
