#ifndef __MC_3DSHADER_H__
#define __MC_3DSHADER_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QGLShaderProgram>

class QObject;
class QString;

class MC_3DShader : public QGLShaderProgram
{
public:

    explicit MC_3DShader(QObject* parent = 0):QGLShaderProgram(parent) {}
    virtual ~MC_3DShader() {}

    bool loadShaderFiles(const QString& vertexShaderFile, const QString& fragmentShaderFile);

#ifndef QT_NO_DEBUG
    void setUniformValue(const char *name, const QMatrix4x4 &value);
    void setUniformValue(const char *name, const QVector3D &value);
    void setUniformValue(const char *name, const QColor &value);
#endif
};

/*! \class MC_3DShader MC_3DShader.h "3DRenderer/3DShaders/MC_3DShader.h"
    \brief Extends the QGLShaderProgram class

    This subclass add a commodity function to load a vertex file + a fragment file and get the shader ready
    Moreover, the class redefined the uniform function to add debug print when uniform variable are not found.
 */

/*! \fn explicit MC_3DShader :: MC_3DShader(QObject* parent = 0)
    \param parent
 */

/*! \fn MC_3DShader :: ~MC_3DShader()
 */

/*! \fn bool MC_3DShader :: loadShaderFiles(const QString& vertexShaderFile, const QString& fragmentShaderFile);
    \brief commodity function to load shader
    \param vertexShaderFile path to the vertex file (GLSL)
    \param fragmentShaderFile path to the fragment file (GLSL)
    \return true if all goes right; false when files are not found or compilation failed
    This function gives precise output in case the files are not found.
    The function needs to be called after getting a valid OpenGL context.
 */

#ifndef QT_NO_DEBUG
/*! \fn void MC_3DShader :: setUniformValue(const char *name, const QMatrix4x4 &value)
    \brief set the value to a uniform variable in a shader
    \param name the name of the variable
    \param value the value to set
 */

/*! \fn void MC_3DShader :: setUniformValue(const char *name, const QVector3D &value);
    \brief set the value to a uniform variable in a shader
    \param name the name of the variable
    \param value the value to set
 */

/*! \fn void MC_3DShader :: setUniformValue(const char *name, const QColor &value);
    \brief set the value to a uniform variable in a shader
    \param name the name of the variable
    \param value the value to set
 */
#endif

#endif
