/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "MC_3DRenderer.h"

#include <QtOpenGL>
#include <QtOpenGL/QGLBuffer>

#include "MC_3DShapeModelList.h"
#include "MC_3DShapeModel.h"
#include "3DShaders/MC_3DShader.h"

MC_3DRenderer :: MC_3DRenderer()
{

}

MC_3DRenderer :: ~MC_3DRenderer()
{
}

bool MC_3DRenderer :: initScene()
{
    glEnable(GL_DEPTH_TEST);

    return true;
}

void MC_3DRenderer :: resizeScene(int width, int height)
{
    glViewport(0,0,width,height);

    m_projectionMatrix.setToIdentity();
    m_projectionMatrix.perspective(60.0, width/static_cast<qreal>(height), 0.1, 600.0);
}

void MC_3DRenderer :: getShapeFrom2DPoint(const QPoint& point, const MC_3DShapeModelList& model)
{
    QVector3D sceneCenter = model.center();
    QMatrix4x4 worldMatrix;
    worldMatrix.translate(-sceneCenter);

    GLint viewport[4] = { 0 };
    GLint errorState = GL_TRUE;

    // We can avoid this get because the viewPort is the following:
    // 0
    // 0
    // winWidth
    // winHeight
    glGetIntegerv(GL_VIEWPORT,viewport);

    GLdouble px0 = 0;
    GLdouble py0 = 0;
    GLdouble pz0 = 0;

    GLdouble px1 = 0;
    GLdouble py1 = 0;
    GLdouble pz1 = 0;

    // viewPort[3]-point.y() invert the y values windows coordinates since OpenGL is starting from bottom of the window !
    errorState &= gluUnProject(point.x(),viewport[3]-point.y(),-1,
                 (worldMatrix * m_camera.viewMatrix()).constData(),m_projectionMatrix.constData(),viewport,
                 &px0,&py0,&pz0);

    errorState &= gluUnProject(point.x(),viewport[3]-point.y(),1,
                 (worldMatrix * m_camera.viewMatrix()).constData(),m_projectionMatrix.constData(),viewport,
                 &px1,&py1,&pz1);

    if ( errorState == GL_FALSE )
    {
        qDebug() << "An error occured when gluUnProject !!!";
    }

    qDebug() << m_camera;
    qDebug() << "Point0: " << px0 << ";" << py0 << ";" << pz0;
    qDebug() << "Point1: " << px1 << ";" << py1 << ";" << pz1;

    m_rayStart = QVector3D(px0,py0,pz0);
    m_rayEnd = QVector3D(px1,py1,pz1);

    model.getClosestIntersectingShape2(m_rayStart,m_rayEnd);
}
