/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "MC_3DRendererGL.h"

#include <QtOpenGL>
#include <QtOpenGL/QGLBuffer>

#include "MC_3DShapeModelList.h"
#include "MC_3DShapeModel.h"
#include "3DShaders/MC_3DShader.h"

const GLfloat lightPosition[]= { 400.0f, 400.0f, 400.0f, 1.0f };
const GLfloat lightSpecular[]= { 1.0f, 1.0f, 1.0f, 1.0f };
const GLfloat matShininess = { 8.0f };

MC_3DRendererGL :: MC_3DRendererGL()
    :MC_3DRenderer()
{

}

MC_3DRendererGL :: ~MC_3DRendererGL()
{
}

bool MC_3DRendererGL :: initScene()
{
    glEnable(GL_DEPTH_TEST);
    glEnable(GL_LIGHTING);
    glEnable(GL_LIGHT0);

    glMaterialfv(GL_FRONT, GL_SPECULAR, lightSpecular);
    glMaterialfv(GL_FRONT, GL_SHININESS, &matShininess);

    return true;
}

bool MC_3DRendererGL :: draw(MC_3DShapeModelList& model)
{
    m_camera.apply();

    QVector3D sceneCenter = model.center();
    QMatrix4x4 worldMatrix;
    worldMatrix.translate(-sceneCenter);

    // Projection matrix
    glMatrixMode(GL_PROJECTION);
    glLoadIdentity();
    glMultMatrixd(m_projectionMatrix.constData());

    // Model view matrix
    glMatrixMode(GL_MODELVIEW);
    glLoadIdentity();
    glMultMatrixd((m_camera.viewMatrix() * worldMatrix).constData());

    glLightfv(GL_LIGHT0, GL_POSITION,lightPosition);

    glEnableClientState(GL_VERTEX_ARRAY);
    glEnableClientState(GL_NORMAL_ARRAY);

    unsigned int nbShapes = model.count();
    for ( unsigned int i = 0 ; i < nbShapes ; i++ )
    {
        MC_3DShapeModel* pShapeModel = model.getShapeModel(i);

        if ( pShapeModel->enabled() )
        {
            GLfloat lightAmbient[]= { pShapeModel->colour().redF(), pShapeModel->colour().greenF(), pShapeModel->colour().blueF(), 1.0f };
            GLfloat lightDiffuse[]= { pShapeModel->colour().redF(), pShapeModel->colour().greenF(), pShapeModel->colour().blueF(), 1.0f };

            glLightfv(GL_LIGHT0, GL_AMBIENT, lightAmbient);
            glLightfv(GL_LIGHT0, GL_DIFFUSE, lightDiffuse);
            glLightfv(GL_LIGHT0, GL_SPECULAR, lightSpecular);

            // const MC_3DShape* pShapeData = pShapeModel->get3DShape();
            pShapeModel->draw();
        }
    }

    glDisableClientState(GL_VERTEX_ARRAY);
    glDisableClientState(GL_NORMAL_ARRAY);

    return true;
}
