/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "MC_3DRendererGL2.h"

#include <QtOpenGL>
#include <QtOpenGL/QGLBuffer>

#include "MC_3DShapeModelList.h"
#include "MC_3DShapeModel.h"
#include "3DShaders/MC_3DShader.h"

MC_3DRendererGL2 :: MC_3DRendererGL2()
    :MC_3DRenderer()
{

}

MC_3DRendererGL2 :: ~MC_3DRendererGL2()
{
}

bool MC_3DRendererGL2 :: draw(MC_3DShapeModelList& model)
{
    m_camera.apply();

    QVector3D sceneCenter = model.center();
    QMatrix4x4 worldMatrix;
    worldMatrix.translate(-sceneCenter);

    QMatrix4x4 worldViewProjectionMatrix = m_projectionMatrix * m_camera.viewMatrix() * worldMatrix;
    QMatrix4x4 invViewMatrix = m_camera.viewMatrix().inverted();

    // Send the matrices to the shader
    if ( m_shader.isLinked() )
    {
        m_shader.bind();

        // m_shader.setUniformValue("worldMatrix",worldMatrix);
        // m_shader.setUniformValue("viewMatrix",m_camera.viewMatrix());
        // m_shader.setUniformValue("projMatrix",m_projectionMatrix);
        m_shader.setUniformValue("worldViewProjMatrix",worldViewProjectionMatrix);
        m_shader.setUniformValue("lightDirection",QVector3D(1.0,1.0,1.0));
        // m_shader.setUniformValue("invViewMatrix",invViewMatrix);
    }

    glEnableClientState(GL_VERTEX_ARRAY);
    glEnableClientState(GL_NORMAL_ARRAY);

    unsigned int nbShapes = model.count();
    for ( unsigned int i = 0 ; i < nbShapes ; i++ )
    {
        MC_3DShapeModel* pShapeModel = model.getShapeModel(i);
        if ( pShapeModel->enabled() )
        {
            if ( m_shader.isLinked() )
            {
                m_shader.setUniformValue("shapeColourAmbient",QColor(pShapeModel->colour().red()/4.0f,pShapeModel->colour().green()/4.0f,pShapeModel->colour().blue()/4.0f));
                m_shader.setUniformValue("shapeColourDiffuse",QColor(pShapeModel->colour().red()/1.5f,pShapeModel->colour().green()/1.5f,pShapeModel->colour().blue()/1.5f));
            }

            pShapeModel->draw();
        }
    }

    if ( m_shader.isLinked() )
    {
        m_shader.release();
    }

    glDisableClientState(GL_VERTEX_ARRAY);
    glDisableClientState(GL_NORMAL_ARRAY);

    glBegin(GL_LINES);
    {
        glColor3f(1.0f,0.0f,0.0f);
        glVertex3f(m_rayStart.x(),m_rayStart.y(),m_rayStart.z());
        glVertex3f(m_rayEnd.x(),m_rayEnd.y(),m_rayEnd.z());
    }glEnd();

    return true;
}

bool MC_3DRendererGL2 :: loadShaderFiles(const QString& vertexShaderFile, const QString& fragmentShaderFile)
{
    return m_shader.loadShaderFiles(vertexShaderFile,fragmentShaderFile);
}
