#ifndef __MC_3DRENDERERGL2_H__
#define __MC_3DRENDERERGL2_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QtOpenGL/QGLBuffer>

#include "MC_3DRenderer.h"

#include "3DShaders/MC_3DShader.h"

class MC_3DShapeModelList;

class MC_3DRendererGL2 : public MC_3DRenderer
{
private:

    MC_3DShader m_shader;           /*!< */

public:

    explicit MC_3DRendererGL2();
    ~MC_3DRendererGL2();

    bool draw(MC_3DShapeModelList& model);

    bool loadShaderFiles(const QString& vertexShaderFile, const QString& fragmentShaderFile);
};

/*! \class MC_3DRendererGL2 MC_3DRendererGL2.h "3DRenderer/MC_3DRendererGL2.h"
    \brief Display the data from a MC_3DRendererModel

    The class assembles the different 3D element to get the scene rendered on screen.
    It uses a camera, a shader and reads data from the MC_3DRendererModel to display it. The class manage the projection matrix through resizeScene()
 */

/*! \fn MC_3DRendererGL2 :: MC_3DRendererGL2()
 */

/*! \fn MC_3DRendererGL2 :: ~MC_3DRendererGL2()
 */

/*! \fn bool MC_3DRendererGL2 :: draw(MC_3DShapeModelList& model)
    \brief draws the scene
    \param model the scene to render
    \return true if all goes right
 */


/*! \fn bool MC_3DRendererGL2 :: loadShaderFiles(const QString& vertexShaderFile, const QString& fragmentShaderFile);
    \brief Loads vertex and fragment shader
    \param vertexShaderFile the path to the vertex shader file
    \param fragmentShaderFile the path to the fragment shader file
    \return true if all goes right
    \see MC_3DShader::loadShaderFiles()
 */

#endif
