#ifndef __MC_SHAPEMODELLIST_H__
#define __MC_SHAPEMODELLIST_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QObject>
#include <QVector>
#include <QVector3D>
#include <QString>

class MC_3DShapeModel;
class MC_3DShape;

class MC_3DShapeModelList : public QObject
{
    Q_OBJECT

private:

    QVector<MC_3DShapeModel*> m_shapes;
    bool m_useVBO;

    QVector3D m_minPoint;       /*!< Minimum point of the scene */
    QVector3D m_maxPoint;       /*!< Maximum point of the scene */

public:

    MC_3DShapeModelList();
    ~MC_3DShapeModelList();

    bool addShape(const QString& name, const MC_3DShape& shape);
    void clear();

    int count()const { return m_shapes.count(); }
    MC_3DShapeModel* getShapeModel(unsigned int index);

    bool contains(const QString& name)const;

    void draw();

    bool useVBO()const { return m_useVBO; }
    void setUseVBO(bool useVBO) { m_useVBO = useVBO; }

    const QVector3D& minPoint()const { return m_minPoint; }
    const QVector3D& maxPoint()const { return m_maxPoint; }
    QVector3D center()const;

    MC_3DShapeModel* getClosestIntersectingShape(const QVector3D& rayStart, const QVector3D& rayEnd)const;
    MC_3DShapeModel* getClosestIntersectingShape2(const QVector3D& rayStart, const QVector3D& rayEnd)const;

    Q_SIGNAL void changed();
};

/*! \class MC_3DShapeModelList MC_3DShapeModelList.h "3DRenderer/MC_3DShapeModelList.h"
    \brief List of model for a 3D shapes

    The shapes are identified in the list by their name.

    It is possible to iterate through the list using count() and getShapeModel().
 */

/*! \fn MC_3DShapeModelList :: MC_3DShapeModelList()
 */

/*! \fn bool MC_3DShapeModelList :: addShape(const QString& name, const MC_3DShape& shape)
    \brief Adds a shape in the list
    \param name shape's name
    \param shape
 */

/*! \fn void MC_3DShapeModelList :: clear()
    \brief removes the shapes loaded
 */

/*! \fn int MC_3DShapeModelList :: count()const
    \brief Returns the number of shapes in the list
    \return
 */

/*! \fn MC_3DShapeModel* MC_3DShapeModelList :: getShapeModel(unsigned int index)
    \brief Returns the shape corresponding to index
    \param index the index of the shape to get
    \return a pointer to the shape
    If there is no shapes in the list, the function returns NULL
    If the index is greater than the number of elements in the list, the function returns the last element
 */

/*! \fn bool MC_3DShapeModelList :: contains(const QString& name)const
    \brief Returns true if a shape named name is found; otherwise returns false
    \return
 */

/*! \fn void MC_3DShapeModelList :: draw()
    \brief Draws the enabled shapes
    \return
 */

/*! \fn bool MC_3DShapeModelList :: useVBO()const
    \brief get if Vertex Buffer Objects are used
    \return true if the VBO are used
 */

/*! \fn void MC_3DShapeModelList :: setUseVBO(bool useVBO)
    \brief toogle Vertex Buffer Objects
    \param useVBO true to enable the use of VBO
 */

/*! \fn const QVector3D& MC_3DShapeModelList :: minPoint()const
    \brief Gets the minimal point of the scene
    \return
 */

/*! \fn const QVector3D& MC_3DShapeModelList :: maxPoint()const
    \brief Gets the maximal point of the scene
    \return
 */

/*! \fn QVector3D MC_3DShapeModelList :: center()const
    \brief Returns the point at the center of the scene (maxPoint+minPoint()/2)
    \return
 */

/*! \fn MC_3DShapeModel* MC_3DShapeModelList :: getClosestIntersectingShape(const QVector3D& rayStart, const QVector3D& rayEnd)const
    Not finished version (still buggy)
    \brief Get the closest shape to the camera intersecting with the ray (rayEnd - rayStart)
    \param rayStart
    \param rayEnd
 */

/*! \fn MC_3DShapeModel* MC_3DShapeModelList :: getClosestIntersectingShape2(const QVector3D& rayStart, const QVector3D& rayEnd)const
    Not finished version (still buggy)
    \brief Get the closest shape to the camera intersecting with the ray (rayEnd - rayStart)
    \param rayStart
    \param rayEnd
 */

/*! \fn void MC_3DShapeModelList :: changed()
    \brief Signal send when a modification of the list has been done
 */

#endif

