#ifndef __MATHUTILS_H__
#define __MATHUTILS_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

static const qreal PI = 3.14159265;
class MathUtils
{
    public:

        static qreal degToRan(qreal angle)
        {
            const static qreal pi180 = PI / 180.0;
            return angle * pi180;
        }

        static qreal ranToDeg(qreal angle)
        {
            const static qreal pi180 = 180.0 / PI;
            return angle * pi180;
        }

        template <typename T>
        static T lerp(T t1, T t2, float t)
        {
            return t1 * (1 - t) + t2 * t;
        }
};

/*! \class MC_3DShader MC_3DShader.h "3DRenderer/3DShaders/MC_3DShader.h"
    \brief Mathematics utility
    Static class to give some useful mathematic related utility
 */

/*! \fn static qreal MathUtils :: degToRan(qreal angle)
    \brief Convert a angle in degree to radian
    \param angle the angle in degree to convert
    \return the angle in radian
    The formula used is rAngle = dAngle * (PI / 180)
 */

/*! \fn static qreal MathUtils :: ranToDeg(qreal angle)
    \brief Convert a angle in radian to degree
    \param angle the angle to convert
    \return the angle in degree
    The formula used is dAngle = 180 * rAngle / PI
 */

/*! \fn static T MathUtils :: lerp(T t1, T t2, float t)
    \brief Apply a linear interpolation between t1 and t2 at time t
    \param t1 the start value
    \param t2 the goal value
    \param t the actual coefficient between 0 and 1
    \return a value between t1 and t2
    The formula used is 't1 * (1 - t) + t2 * t'
 */

#endif
