/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QMenu>

#include "MC_3DShapeListWidget.h"

#include "MC_3DShapeWidgetItem.h"
#include "3DRenderer/MC_3DShapeModelList.h"
#include "3DRenderer/MC_3DShapeModel.h"

MC_3DShapeListWidget :: MC_3DShapeListWidget(MC_3DShapeModelList* pShapeList, QWidget* parent)
    :QListWidget(parent),m_contextMenu(this),m_pShapeList(pShapeList)
{
    Q_ASSERT(pShapeList);

    {
        pEnablerAction = m_contextMenu.addAction(tr("Show shape"),this,SLOT(toogleShowShape(bool)));
        pEnablerAction->setCheckable(true);
        pEnablerAction->setChecked(true);
    }

    {
        m_contextMenu.addAction(tr("Change colour"),this,SLOT(changeColourShape()));
    }

    connect(pShapeList,SIGNAL(changed()),this,SLOT(update()));
}

bool MC_3DShapeListWidget :: integrateShapes()
{
    unsigned int nbShapes = m_pShapeList->count();
    for ( unsigned int i = 0 ; i < nbShapes ; i++ )
    {
        this->addItem(
                    new MC_3DShapeWidgetItem(m_pShapeList->getShapeModel(i)->name())
                    );
    }

    return true;
}

void MC_3DShapeListWidget :: update()
{
    this->clear();
    this->integrateShapes();
}

void MC_3DShapeListWidget :: contextMenuEvent(QContextMenuEvent * pCME)
{
    pCME->accept();

    if ( this->itemAt(pCME->pos()) != NULL )
    {
        pEnablerAction->setChecked(m_pShapeList->getShapeModel(this->row(this->itemAt(pCME->pos())))->enabled());
        m_contextMenu.popup(pCME->globalPos());
    }
}

void MC_3DShapeListWidget :: toogleShowShape(bool checked)
{
    foreach(QListWidgetItem* pItem, this->selectedItems())
    {
        m_pShapeList->getShapeModel(this->row(pItem))->setEnabled(checked);
    }
}

void MC_3DShapeListWidget :: changeColourShape()
{
    QColor newColour = QColorDialog::getColor(Qt::white,this);
    if ( newColour.isValid() )
    {
        foreach(QListWidgetItem* pItem, this->selectedItems())
        {
            m_pShapeList->getShapeModel(this->row(pItem))->setColour(newColour);
        }
    }
}
