#include <QtGui/QApplication>
#include "mainwindow.h"

#include <ctime>

#ifndef QT_NO_DEBUG
    #ifndef LOG_IN_FILE
        #define LOG_IN_FILE 0
    #endif
#else
    // Shutdown all debugging information
    #define QT_NO_DEBUG_OUTPUT
    #define LOG_IN_FILE 0
#endif

#if LOG_IN_FILE
    #include <QDebug>
    #include <QFile>
    #include <QByteArray>

    QFile* pDebugFile = NULL;

    void debugFileHandler(QtMsgType type, const char *msg)
    {
        // Test to protect from some human errors (can be removed)
        if ( pDebugFile && pDebugFile->isOpen() )
        {
            switch (type)
            {
             case QtDebugMsg:
                 pDebugFile->write(QByteArray(msg) + QByteArray("\n"));
                 break;
             case QtWarningMsg:
                 pDebugFile->write(QByteArray("Warning: ") + QByteArray(msg) + QByteArray("\n"));
                 break;
             case QtCriticalMsg:
                 pDebugFile->write(QByteArray("Critical: ") + QByteArray(msg) + QByteArray("\n"));
                 break;
             case QtFatalMsg:
                 pDebugFile->write(QByteArray("Fatal: ") + QByteArray(msg) + QByteArray("\n"));
                 abort();
             }
        }
    }
#endif

int main(int argc, char* argv[])
{
#if LOG_IN_FILE
    pDebugFile = new QFile("debug.log");
    pDebugFile->open(QIODevice::WriteOnly);
    qInstallMsgHandler(debugFileHandler);
    qDebug() << "Log in file started";
#endif

    qsrand(time(NULL));

    int error = 0;

    // Creating a block to let the destruction messages in the logger
    {
        QApplication a(argc, argv);
        MainWindow w;
        w.show();

        error = a.exec();
    }

#if LOG_IN_FILE
    qDebug() << "Log in file closed";
    pDebugFile->close();
    delete pDebugFile;
    pDebugFile = NULL;
    // Thanks to this, we don't try to use a file closed
    qInstallMsgHandler(0);
#endif

    return error;
}
