#include "ECGRenderer.h"

#include <cassert>

#include "Types/ECGList.h"

void ECGRenderer :: generatePaths()
{
    m_paths.clear();

    m_yFactor = m_surfaceSize.height() / (m_pList->min() - m_pList->max()) / 2;

    foreach ( ECG ecg, m_pList->getList())
    {
        QPainterPath path;

        int halfHeigh = m_surfaceSize.height()/2;
        path.moveTo(0,halfHeigh);
        const QList<float>& data = ecg.data();
        float xDiv = m_surfaceSize.width() / static_cast<float>(data.size());
        for ( int i = 0 ; i < data.size() ; i++ )
        {
            path.lineTo(i*xDiv,halfHeigh + data[i] * m_yFactor);
        }

        m_paths.append(path);
    }
}

void ECGRenderer :: setECGList(const ECGList* pList)
{
    assert(pList);
    m_pList = pList;

    this->generatePaths();
}

void ECGRenderer :: paint(QPainter* pPainter)
{
    assert(pPainter);

    static QPen blackPen = QPen(QColor(0, 0, 0), 1, Qt::SolidLine);
    static QPen greyPen = QPen(QColor(128, 128, 128), 1, Qt::SolidLine);

    if ( m_paths.size() != 0 )
    {
        int i = 0;
        for ( int h = m_surfaceSize.height()/2 ; h > 0 ; h -= qAbs(m_yFactor) * 0.1f , i++ )
        {
            pPainter->setPen(blackPen);
            pPainter->drawText(0,h,QString::number(i*0.1f));
            pPainter->setPen(greyPen);
            pPainter->drawLine(0,h,m_surfaceSize.width(),h);
        }

        i = 0;
        for ( int h = m_surfaceSize.height()/2 ; h < m_surfaceSize.height() ; h += qAbs(m_yFactor) * 0.1f , i++ )
        {
            pPainter->setPen(blackPen);
            pPainter->drawText(0,h,QString::number(i*0.1f));
            pPainter->setPen(greyPen);
            pPainter->drawLine(0,h,m_surfaceSize.width(),h);
        }

        i = 0;
        const QList<ECG>& data = m_pList->getList();
        foreach(QPainterPath path, m_paths)
        {
            pPainter->setPen(QPen(data[i].color(), 2, Qt::SolidLine));
            pPainter->drawPath(path);
            i++;
        }
    }
}
