#ifndef __ECGRENDERER_H__
#define __ECGRENDERER_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QList>
#include <QPainterPath>
#include <QPainter>

class ECGList;

class ECGRenderer
{
private:
    const ECGList* m_pList;         /*!< List of ECG to draw */
    QList<QPainterPath> m_paths;    /*!< ECG graphical representation */
    QSize m_surfaceSize;            /*!< */

    float m_yFactor;                /*!< Y Scaling */

public:
    ECGRenderer(const ECGList* pList, const QSize& surfaceSize):m_pList(pList),m_surfaceSize(surfaceSize) {}

    void generatePaths();

    void setECGList(const ECGList* pList);
    void setSurfaceSize(const QSize& surfaceSize) { m_surfaceSize = surfaceSize; this->generatePaths(); }

    void paint(QPainter* pPainter);
};

/*! \class ECGRenderer ECGRenderer.h "ECGRenderer.h"
    \brief Renderer to draw ECG
 */

/*! \fn ECGRenderer :: ECGRenderer(const ECGList* pList, const QSize& surfaceSize)
    \param pList the list to display
    \param surfaceSize
  */

/*! \fn void ECGRenderer :: generatePaths()
    \brief Generates the path to draw
  */

/*! \fn void ECGRenderer :: setECGList(const ECGList* pList)
    \brief Defines a new list to display
    \param pList the new list
 */

/*! \fn void ECGRenderer :: setSurfaceSize(const QSize& surfaceSize)
    \brief Change the render surface size
    \param surfaceSize
  */

/*! \fn void ECGRenderer :: paint(QPainter* pPainter)
    \brief paint the ECG paths
    \param pPainter the painter to use
  */

#endif
