#ifndef __ECGVIEWERWIDGET_H__
#define __ECGVIEWERWIDGET_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QWidget>

#include "Parser/ECGParserFactory.h"
#include "Types/ECGList.h"
#include "ECGRenderer.h"

class Logger;

class ECGViewerWidget : public QWidget
{
    Q_OBJECT

private:
    ECGParserFactory m_parsersFactory;  /*!< */
    ECGList m_ecgList;                  /*!< */

    ECGRenderer m_renderer;             /*!< */

    Logger* m_pLogger;                  /*!< */

protected:

    void paintEvent(QPaintEvent* pPaintEvent);
    void resizeEvent(QResizeEvent* pResizeEvent);

public:
    explicit ECGViewerWidget(Logger* pLogger, QWidget* parent=0);
    ~ECGViewerWidget();

    Q_SLOT void clearData();

    Q_SLOT void loadECGFile(const QString& name, const QByteArray& file);
    Q_SLOT void loadECGFiles();
};

/*! \class ECGViewerWidget ECGViewerWidget.h "ECGViewerWidget.h"
    \brief Widget to visualise the ECG graphs
 */

/*! \fn void ECGViewerWidget :: paintEvent(QPaintEvent* pPaintEvent)
    \brief Draw the widget
    \param pPaintEvent the paint event information
 */

/*! \fn void ECGViewerWidget :: resizeEvent(QResizeEvent* pResizeEvent)
    \brief Handles the resize of the widget
    \param pResizeEvent information on the resize
 */

/*! \fn explicit ECGViewerWidget :: ECGViewerWidget(Logger* pLogger, QWidget* parent=0)
    \param pLogger logger where to store information
    \param parent
 */

/*! \fn ECGViewerWidget :: ~ECGViewerWidget()
 */

/*! \fn void ECGViewerWidget :: clearData()
    Clears previously loaded data
 */

/*! \fn void ECGViewerWidget :: loadECGFile(const QString& name, const QByteArray& file)
 *  \brief Loads an ECG from a QByteArray
 *  \param name the name of the ECG
 *  \param file the data from where to read the shape data
 */

/*! \fn void ECGViewerWidget :: loadECGFiles()
    \brief Opens a file dialog to load ECG files
 */

#endif
