#ifndef __ECGPASER_H__
#define __ECGPASER_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

class QString;
class QByteArray;

class ECGList;

class ECGParser
{
protected:

    virtual bool parseData(const QByteArray& dataArray, ECGList& ecgList, const QString& ecgName)=0;

public:

    virtual ~ECGParser() {}
    bool parse(const QString& fileName, ECGList& ecgList);
    bool parse(const QByteArray& dataArray, ECGList& ecgList, const QString& ecgName);
};

/*! \class ECGParser ECGParser.h "Parser/ECGParser.h"
    \brief Virtual class for ECG file parsers

    Implements the function to parse the file and put the data in the ECGList
 */

/*! \fn virtual ECGParser::~ECGParser()=0;
 */

/*! \fn virtual bool ECGParser :: parseData(const QByteArray& dataArray, ECGList &ecgList, const QString& ecgName)=0
    \brief Parse an ECG from a QByteArray to put it in a list
    \param dataArray the data to parse
    \param ecgList the list to fill
    \param ecgName the name of the new ECG
    \return true if all goes right
 */

/*! \fn virtual bool ECGParser::parse(const QString& fileName, ECGList& ecgList)=0;
    \brief Reads a file to extract the information about an ECG
    \param fileName the path to the file to read from
    \param ecgList the list of ECGs where to put the new ECG
    \return true if all goes right ; false if the file is not open or not correctly formatted
 */

/*! \fn bool ECGParser :: parse(const QByteArray& dataArray, ECGList& ecgList, const QString& ecgName)
    \brief Parse an ECG from a QByteArray
    \param dataArray the data to read
    \param ecgList the list to fill
    \param ecgName the name of the new ECG
  */

#endif
