import QtQuick 1.0

Rectangle
{
    width: 500
    height: 500

    signal patientNameChanged(string newName)
    signal patientAgeChanged(string newAge)

    signal operationNameChanged(string oldName, string newName)
    signal operationDateChanged(string operationName, string newDate)
    signal operationObservationChanged(string operationName, string newObservation)
    signal operationNew()

    signal fileNew(string category, string folder);
    signal fileCategoryChanged(string oldCategory,string newCategory,string folderName,string fileName)
    signal fileFolderChanged(string oldCategory,string oldFolder,string newFolder,string fileName)
    signal fileRemoved(string category, string folder, string fileName)

    ListView
    {
        id: patientDataView
        width: parent.width
        model: patientData
        height: parent.height/3
        delegate: PatientDataEdit
        {
            pName: name
            pAge: age

            onNameChanged: { patientNameChanged(newName) }
            onAgeChanged: { patientAgeChanged(newAge) }
        }
    }

    ListView
    {
        id: patientOperationList

        anchors.top: patientDataView.bottom
        width: parent.width
        height: parent.height/3

        model: patientOperationData

        header:
            ListViewHeader
            {
                height: 15
                headerText: "Operations: "
            }

        delegate:
            OperationDataEdit
            {
                // width: parent.width
                oDate: date
                oName: name
                oObservation: observation

                Item
                {
                    id: keeper;
                    property string keep: name;
                }

                onNameChanged: { operationNameChanged(keeper.keep,newName); keeper.keep = newName }
                onDateChanged: { operationDateChanged(oName,newDate) }
                onObservationChanged: { operationObservationChanged(oName,newObservation) }
            }


    }

    Button
    {
        id: operationButton

        anchors.top: patientOperationList.bottom
        width: parent.width
        height: 20

        title: "Add operation"

        onButtonClick: { operationNew() }
    }

    ListView
    {
        id: listFiles
        width: parent.width
        height: parent.height/3 - 70
        model: fileDataModel
        snapMode: "SnapToItem"
        highlightRangeMode: "ApplyRange"

        anchors.top: operationButton.bottom

        header:
            ListViewHeader
            {
                height: 15
                headerText: "Ressources: "
            }
        delegate:
            FileDataEdit
            {
                Item
                {
                    id: keeperCategory;
                    property string keep: category;
                }

                Item
                {
                    id: keeperFolder;
                    property string keep: folderName;
                }

                height: 20
                categoryText: category
                folderText: folderName
                pathText: fileName

                onCategoryChanged: { fileCategoryChanged(keeperCategory.keep,newCategory,folderName,fileName) ; keeperCategory.keep = newCategory }
                onFolderChanged: { fileFolderChanged(category,keeperFolder.keep,newFolder,fileName) ; keeperFolder.keep = newFolder }

                onRemoved: { fileRemoved(category,folder,fileName) }
            }
    }

    Rectangle
    {
        id: addFileBox

        width: parent.width
        height: 100

        anchors.top:  listFiles.bottom

        TextInformationEdit
        {
            id: categoryEdit
            width: 200

            labelText: "Category: "
            text: ""

            onInformationChanged: { text = newInfo }
        }

        TextInformationEdit
        {
            id: folderEdit
            width: 200

            anchors.right: parent.right
            anchors.rightMargin: 5

            labelText: "Folder: "
            text: ""

            onInformationChanged: { text = newInfo }
        }

        Button
        {
            width: parent.width
            height: 12

            anchors.top: folderEdit.bottom

            title: "Add new"

            onButtonClick: { fileNew(categoryEdit.text, folderEdit.text) }
        }
    }
}
