#ifndef __MODULEINTERFACE_H__
#define __MODULEINTERFACE_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QWidget>
#include <QString>
#include <QUrl>

#include "Types/Patient.h"

class ModuleInterface
{
private:

protected:
    QString m_moduleName;   /*!< */
    QUrl m_logoSource;      /*!< */

public:
    virtual ~ModuleInterface() {}

    virtual void createGui(QWidget* parent = 0)=0;
    virtual void setPatientData(Patient* pPatient, const QString& folderName)=0;
    virtual bool needDisplay()=0;

    virtual const QString& name()=0;
    virtual const QUrl& imageSource()=0;

    virtual QWidget* getWidget()=0;

    Q_SIGNAL virtual void clientChanged(Patient* pPatient)=0;
};

Q_DECLARE_INTERFACE(ModuleInterface,
                    "geekologues.MedCenter.ModuleInterface/1.0")

/*! \class ModuleInterface ModuleInterface.h "Module/ModuleInterface.h"
    \brief Base class for MedCenter's modules
    Modules can display a widget ; have access to Patient data and should give their name and a path to an logo image
    A module does not always need to be displayed. This depends on the information attached to the Patient.
 */

/*! \fn virtual ModuleInterface :: ~ModuleInterface()
 */

/*! \fn virtual void ModuleInterface :: createGui(QWidget* parent =0)=0
    \brief Construct the interface of the module using <a>parent</a>
    \param parent
 */

/*! \fn virtual void ModuleInterface :: setPatientData(Patient* pPatient, const QString& folderName)=0
    \brief Defines the Patient data for the module
    \param pPatient the data
    \param folderName the folder to use
 */

/*! \fn virtual bool ModuleInterface :: needDisplay()=0
    \brief Informs if the module should be displayed
    \return true if the module has something to show depending on the Patient data
 */

/*! \fn virtual const QString& ModuleInterface :: name()=0
    \return the name of the module
 */

/*! \fn virtual const QUrl& ModuleInterface :: imageSource()=0
    \return the path to the logo image
 */

/*! \fn virtual QWidget* ModuleInterface :: getWidget()=0
    \brief Gets the widget created by the module
    \return a pointer to the widget
 */

/*! \fn virtual void ModuleInterface :: clientChanged(Patient* pPatient)=0
    \brief Signal sent when the patient data changed
    \param pPatient pointer to the patient data
 */

#endif
