/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "NServer.h"

#include <QTcpServer>

#include "Network/Utils/DataUtils.h"
#include "Logger/Logger.h"

NServer :: NServer(quint16 port, Logger* pLogger, QObject* parent)
    :QTcpServer(parent),m_pLogger(pLogger)
{
    this->listen(QHostAddress::Any, port);
}

NServer :: ~NServer()
{
    foreach(NServerSocket* pSocket, m_sockets)
    {
        delete pSocket;
    }
}

void NServer :: reportError(QAbstractSocket::SocketError error)
{
    m_pLogger->warning("An error occured: " + error);
}

void NServer :: dataReceived()
{
    m_pLogger->debug("NServer::appendData()");
    foreach(NServerSocket* pSocket, m_sockets)
    {
        while ( pSocket->m_pSocket->atEnd() != true ) // Can be an if ?
        {
            if ( pSocket->m_remainingBytes == 0 )
            {
                // Read the size of the data to get
                char* pDataLength = new char[4];
                if ( pDataLength )
                {
                    int nbBytes = pSocket->m_pSocket->read(pDataLength,4);
                    if ( nbBytes != 4 )
                    {
                        qDebug() << "Problem when reading the size of the paquet";
                        break;
                    }

                    pSocket->m_remainingBytes = DataUtils::charDWordToInt(pDataLength);

                    // Now that we know the size of the data to read, lets read it
                }

                delete pDataLength;
            }

            // First, allocate the buffer to accept these data
            int bytesToRead = qMin(qint64(pSocket->m_remainingBytes),pSocket->m_pSocket->bytesAvailable()); // we avoid to allocate an amount of data if we can't get these data
            char* pDataBuffer = new char[bytesToRead];
            if ( pDataBuffer )
            {
                int nbBytes = pSocket->m_pSocket->read(pDataBuffer,bytesToRead);
                if ( nbBytes != bytesToRead )
                {
                    qDebug() << "Fail to read data on Network";
                }
                else
                {
                    pSocket->m_dataBuffer.append(QByteArray(pDataBuffer,bytesToRead));
                    pSocket->m_remainingBytes -= nbBytes;
                    if ( pSocket->m_remainingBytes == 0 )
                    {
                        emit dataReceived(pSocket->m_dataBuffer);
                        pSocket->m_dataBuffer.clear();
                    }
                    else if ( pSocket->m_remainingBytes < 0 )
                    {
                        qWarning() << "BUG happened on Network";
                    }
                }
            }
            else
            {
                qDebug() << "Failed to allocate " << bytesToRead << "bytes for Network";
            }

            delete pDataBuffer;
        }
    }
}

void NServer :: cleanUp()
{
    foreach(NServerSocket* pSocket, m_sockets)
    {
        if ( pSocket->m_pSocket->isValid() == false)
        {
            delete pSocket;
            m_sockets.removeOne(pSocket);
            m_pLogger->debug("Removed invalid socket");
        }
    }
}
