#ifndef __NSERVER_H__
#define __NSERVER_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QAbstractSocket>
#include <QTcpServer>
#include <QByteArray>

class Logger;

class NServer : public QTcpServer
{
    Q_OBJECT

protected:
    struct NServerSocket
    {
        QAbstractSocket* m_pSocket; /*!< */
        int m_remainingBytes;       /*!< Remaining bytes to read to complete the data segment */
        QByteArray m_dataBuffer;    /*!< Container for the data segment */

        NServerSocket(QAbstractSocket* pSocket):m_pSocket(pSocket),m_remainingBytes(0) {}
        ~NServerSocket() { m_pSocket->deleteLater(); }
    };

protected:

    Logger* m_pLogger;                  /*!< */
    QList<NServerSocket*> m_sockets;    /*!< list of connected sockets */

    Q_SLOT void dataReceived();
    Q_SLOT void reportError(QAbstractSocket::SocketError error);
    Q_SLOT void cleanUp();

public:

    NServer(quint16 port, Logger* pLogger, QObject* parent = 0);
    virtual ~NServer();

    Q_SIGNAL void dataReceived(QByteArray data);
};

/*! \class NServer NServer.h "Network/Server/NServer.h"
    \brief Base class for servers
 */

/*! \struct NServer::NServerSocket NServer.h "Network/Server/NServer.h"
    \brief Internal structure to keep information on incoming connection and data
*/

/*! \fn NServer::NServerSocket::NServerSocket(QAbstractSocket* pSocket)
    \param pSocket the incoming socket
*/

/*! \fn NServer::NServerSocket::~NServerSocket()
    \brief close the socket connection
 */

/*! \fn void NServer :: dataReceived()
    \brief Slot called when new data are received
    Will append these data to the rest of data already received on this socket. If more data still needed to be read, the client will try to read
    Otherwise, the signal dataReceived is send with the data
 */

/*! \fn void NServer :: reportError(QAbstractSocket::SocketError error)
    \brief Reports a socket error
    \param error
 */

/*! \fn void NServer :: cleanUp()
    \brief Disconnect all sockets invalid (Keep the valid ones)
 */

/*! \fn NServer::NServer(quint16 port, Logger* pLogger, QObject* parent = 0)
    \param port the connection port
    \param pLogger
    \param parent
 */

/*! \fn virtual NServer::~NServer()
 */

/*! \fn void NServer::dataReceived(QByteArray data)
    \brief Signal sent when complete data are received
    \param data the data received
 */


#endif
