#ifndef __MACHINEDATA_H__
#define __MACHINEDATA_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QObject>
#include <QDebug>

class MachineData : public QObject
{
    Q_OBJECT

    Q_PROPERTY(QString ipAddress READ ipAddress CONSTANT)
    Q_PROPERTY(QString machineName READ machineName CONSTANT)

private:
    QString m_ipAddress;    /*!< */
    QString m_machineName;  /*!< */

public:
    MachineData(const QString& ipAddress, const QString& machineName)
        :m_ipAddress(ipAddress),m_machineName(machineName) {}

    MachineData(const MachineData& machineData)
        :QObject(machineData.parent()),m_ipAddress(machineData.ipAddress()),m_machineName(machineData.machineName()) {}

    MachineData& operator=(const MachineData& machineData);

    bool operator==(const MachineData& machineData)
    {
        return this->m_ipAddress == machineData.ipAddress();
    }

    const QString& ipAddress()const { return m_ipAddress; }
    const QString& machineName()const { return m_machineName; }
};

QDebug operator<<(QDebug dbg, const MachineData& md);

/*! \class MachineData MachineData.h "Network/Types/MachineData.h"
    \brief Type to keep information about other machines on the network
 */

/*! \fn MachineData::MachineData(const QString& ipAddress, const QString& machineName)
    \param ipAddress
    \param machineName
 */

/*! \fn MachineData::MachineData(const MachineData& machineData)
    \brief
    \param machineData
 */

/*! \fn MachineData& MachineData::operator=(const MachineData& machineData);
    \brief
    \param machineData
 */

/*! \fn bool MachineData::operator==(const MachineData& machineData)
    \brief Compares two MachineData based on IP
    \param machineData
*/

/*! \fn const QString& MachineData::ipAddress()const
    \brief
    \return
 */

/*! \fn const QString& MachineData::machineName()const
    \brief
    \return
 */

#endif
