#ifndef __DATA_H__
#define __DATA_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QObject>
#include <QString>
#include <QByteArray>

class Patient;

class Data : public QObject
{
    Q_OBJECT

public:
    enum SegmentDataIdentifier
    {
        SDI_Version = 10,
        SDI_Patient = 100, // We init at 100 to be able to debug "easily" (it also means, that the data are more limited in the identifier numbers, but 99 ids should be enough)
        SDI_Operation = 200,
        SDI_File = 300
    };

protected:
    QString m_category; /*!< */

public:
    Data(const QString& category, QObject* parent=0):QObject(parent),m_category(category) {}
    virtual ~Data() {}

    virtual QByteArray data()const =0;
    virtual int load(const QByteArray& data, int index=0)=0;

    static void factory(Patient* pPatient, const QByteArray& data, int index=0, int* nbRead=NULL);

    const QString& category()const { return m_category; }
};

/*! \class Data Data.h "Types/Data.h"
    \brief base class for data ready to be shared on network
 */

/*! \enum Data::SegmentDataIdentifier
    Identifier to recognise data when receiving messages from the network
 */

/*! \fn Data::Data(const QString& category, QObject* parent=0)
    \param category the category of the data (kind of folder for Patient)
    \param parent
 */

/*! \fn virtual Data::~Data()
 */

/*! \fn virtual QByteArray Data::data()const =0
    \brief Gets the data in the form of a QByteArray (ready to be shared on the network)
    \return
 */

/*! \fn virtual int Data::load(const QByteArray& data, int index=0)=0
    \brief load some data from a QByteArray
    \param data the data to load
    \param index the where to read
    \return the number of bytes read
 */

/*! \fn static void Data::factory(Patient* pPatient, const QByteArray& data, int index=0, int* nbRead=NULL)
    \brief Read all the Data available in <a>data</a> and fill <a>pPatient</a> with
    \param pPatient the Patient to complete
    \param data the data to read from
    \param index the index where to start to read
    \param nbRead if not NULL, will contain the number of bytes read
 */

/*! \fn const QString& Data::category()const
    \brief Returns the category
 */


#endif
