/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "FileData.h"

#include "Utils/ByteArrayUtils.h"

#include <QDebug>

QByteArray FileData :: data()const
{
    QByteArray dataArray;

    ByteArrayUtils::writeNumber<int>(dataArray,SDI_File);

    ByteArrayUtils::writeNumber<int>(dataArray,FDI_CATEGORY);
    ByteArrayUtils::writeString(dataArray,m_category);

    if ( !m_name.isEmpty() )
    {
        ByteArrayUtils::writeNumber<int>(dataArray,FDI_NAME);
        ByteArrayUtils::writeString(dataArray,m_name);
    }

    if ( !m_folder.isEmpty() )
    {
        ByteArrayUtils::writeNumber<int>(dataArray,FDI_FOLDER);
        ByteArrayUtils::writeString(dataArray,m_folder);
    }

    ByteArrayUtils::writeNumber<int>(dataArray,FDI_DATA);
    ByteArrayUtils::writeData(dataArray,m_data);

    return dataArray;
}

int FileData :: load(const QByteArray& data, int index)
{
    int localIndex = index;
    bool canReadData = true;

    while ( canReadData && localIndex < data.size()  )
    {
        int nbReadType = 0;
        int dataType = ByteArrayUtils::readNumber(data,localIndex,&nbReadType);
        if (nbReadType == -1)
        {
            qDebug() << "Fail to read the type of data for FileData";
            return -1;
        }

        localIndex+=nbReadType;

        switch (dataType)
        {
        case FDI_CATEGORY:
            {
                int byteRead = 0;
                m_category = ByteArrayUtils::readString(data,localIndex,&byteRead);
                if ( byteRead == -1 )
                {
                    qDebug() << "FileData: failed to read name";
                    canReadData = false;
                }

                localIndex += byteRead;
            }
            break;
        case FDI_NAME:
            {
                int byteRead = 0;
                m_name = ByteArrayUtils::readString(data,localIndex,&byteRead);
                if ( byteRead == -1 )
                {
                    qDebug() << "FileData: failed to read name";
                    canReadData = false;
                }

                localIndex += byteRead;
            }
            break;
        case FDI_FOLDER:
            {
                int byteRead = 0;
                m_folder = ByteArrayUtils::readString(data,localIndex,&byteRead);
                if ( byteRead == -1 )
                {
                    qDebug() << "FileData: failed to read folder name";
                    canReadData = false;
                }

                localIndex += byteRead;
            }
            break;
        case FDI_DATA:
            {
                int byteRead = 0;
                m_data = ByteArrayUtils::readData(data,localIndex,&byteRead);
                if ( byteRead == -1 )
                {
                    qDebug() << "FileData: failed to read file data";
                    canReadData = false;
                }

                localIndex += byteRead;
            }
            break;
        default:
            // Id not recognised, another kind of data, let others determine the data
            localIndex-=nbReadType;
            canReadData=false;
            break;
        }
    }

    return localIndex-index;
}
