#ifndef __LISTDATA_H__
#define __LISTDATA_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "Data.h"

#include <QList>
#include <QDebug>

#include <typeinfo>
#include <cassert>

template <typename T>
class ListData : public Data
{
private:
    QList<T*> m_datas;

public:
    ListData():Data("ListData") {}
    ~ListData()
    {
        foreach(T* pData, m_datas)
        {
            delete pData;
        }
    }

    void add(T* pData)
    {
        if ( pData )
        {
            m_datas.append(pData);
        }
    }

    const QList<T*>& dataList()const { return m_datas; }

    QByteArray data()const
    {
        QByteArray dataArray;
        foreach(T* pData, m_datas)
        {
            dataArray += pData->data();
        }

        return dataArray;
    }

    int load(const QByteArray& data, int index=0)
    {
        T* pData = new T();
        if ( pData == NULL )
        {
            qDebug() << "Fail to allocate memory for " << typeid(T).name();
            return -1;
        }

        int nbRead = pData->load(data,index);
        if ( nbRead != -1 )
        {
            this->add(pData);
        }
        else
        {
            qDebug() << "Fail to read OperationData";
        }

        return nbRead;
    }

    void remove(T* pData)
    {
        assert(pData);

        m_datas.removeOne(pData);
    }
};

/*! \class ListData ListData.h "Types/ListData.h"
    \brief List implementation ready to be shared on network.
 */

/*! \fn ListData::ListData()
 */

/*! \fn ListData::~ListData()
    \brief Free all the Data contained
 */

/*! \fn void ListData::add(T* data)
    \brief Adds a new data in the list
    \param data
 */

/*! \fn const QList<T*>& ListData::dataList()const
    \brief Gets the data
    \return
*/

/*! \fn void ListData::remove(T* pData)
    \brief Removes an element from the list
    \param pData pointer to the element to remove
 */

#endif
