/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "OperationData.h"

#include <QDebug>

#include "Utils/ByteArrayUtils.h"

QByteArray OperationData :: data() const
{
    QByteArray dataArray;

    ByteArrayUtils::writeNumber<int>(dataArray,SDI_Operation);
    if ( !m_name.isEmpty() )
    {
        ByteArrayUtils::writeNumber<int>(dataArray,ODI_NAME);
        ByteArrayUtils::writeString(dataArray,m_name);
    }

    if ( m_date.isValid() )
    {
        ByteArrayUtils::writeNumber<int>(dataArray,ODI_DATE);
        ByteArrayUtils::writeDate(dataArray,m_date);
    }

    if ( m_observation.isEmpty() )
    {
        ByteArrayUtils::writeNumber<int>(dataArray,ODI_OBSERVATION);
        ByteArrayUtils::writeString(dataArray,m_observation);
    }

    return dataArray;
}

int OperationData :: load(const QByteArray &data, int index)
{
    int localIndex = index;
    bool canReadData = true;

    while ( canReadData && localIndex < data.size()  )
    {
        int nbReadType = 0;
        int dataType = ByteArrayUtils::readNumber(data,localIndex,&nbReadType);
        if (nbReadType == -1)
        {
            qDebug() << "Fail to read the type of data for OperationData";
            return -1;
        }

        localIndex+=nbReadType;

        switch (dataType)
        {
        case ODI_NAME:
            {
                int byteRead = 0;
                m_name = ByteArrayUtils::readString(data,localIndex,&byteRead);
                if ( byteRead == -1 )
                {
                    qDebug() << "OperationData: failed to read name";
                    canReadData = false;
                }

                localIndex += byteRead;
            }
            break;
        case ODI_DATE:
            {
                int byteRead = 0;
                m_date = ByteArrayUtils::readDate(data,localIndex,&byteRead);
                if ( byteRead == -1 )
                {
                    qDebug() << "OperationData: failed to read date";
                    canReadData = false;
                }

                localIndex += byteRead;
            }
            break;
        case ODI_OBSERVATION:
            {
                int byteRead = 0;
                m_observation = ByteArrayUtils::readString(data,localIndex,&byteRead);
                if ( byteRead == -1 )
                {
                    qDebug() << "OperationData: failed to read observation";
                    canReadData = false;
                }

                localIndex += byteRead;
            }
            break;
        default:
            // Id not recognised, another kind of data, let others determine the data
            localIndex-=nbReadType;
            canReadData=false;
            break;
        }
    }

    return localIndex-index;
}

OperationData* OperationData::searchName(const QList<OperationData*>& list, const QString& name)
{
    foreach(OperationData* pOperationData, list)
    {
        if (pOperationData->name() == name)
        {
            return pOperationData;
        }
    }

    qDebug() << "SearchName:: Name not found";
    return NULL;
}
