/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "PatientData.h"

#include <QByteArray>
#include <QDebug>

#include "Utils/ByteArrayUtils.h"

QByteArray PatientData :: data()const
{
    QByteArray dataArray;

    ByteArrayUtils::writeNumber<int>(dataArray,SDI_Patient);
    if ( !m_name.isEmpty() )
    {
        ByteArrayUtils::writeNumber<int>(dataArray,PDI_NAME);
        ByteArrayUtils::writeString(dataArray,m_name);
    }

    if ( m_age != -1 )
    {
        ByteArrayUtils::writeNumber<int>(dataArray,PDI_AGE);
        ByteArrayUtils::writeNumber<short int>(dataArray,m_age);
    }

    return dataArray;
}

int PatientData :: load(const QByteArray& data, int index)
{
    int localIndex = index;
    bool canReadData = true;

    while ( canReadData && localIndex < data.size()  )
    {
        int nbReadType = 0;
        int dataType = ByteArrayUtils::readNumber(data,localIndex,&nbReadType);
        if (nbReadType == -1)
        {
            qDebug() << "Fail to read the type of data for PatienData";
            return -1;
        }

        localIndex+=nbReadType;

        switch (dataType)
        {
        case PDI_NAME:
            {
                int byteRead = 0;
                m_name = ByteArrayUtils::readString(data,localIndex,&byteRead);
                if ( byteRead == -1 )
                {
                    qDebug() << "PatientData: failed to read name";
                    canReadData = false;
                }

                localIndex += byteRead;
            }
            break;
        case PDI_AGE:
            {
                int byteRead = 0;
                m_age = ByteArrayUtils::readNumber(data,localIndex,&byteRead);
                if ( byteRead == -1 )
                {
                    qDebug() << "PatientData: failed to read age";
                    canReadData = false;
                }

                localIndex += byteRead;
            }
            break;
        default:
            localIndex-=nbReadType;
            canReadData=false;
            break;
        }
    }

    return localIndex-index;
}
