#ifndef __USER_H__
#define __USER_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QObject>

class User : public QObject
{
    Q_OBJECT

    Q_PROPERTY(QString name READ name CONSTANT)
    Q_PROPERTY(int category READ category CONSTANT)
    Q_PROPERTY(bool isOnline READ isOnline CONSTANT)

public:

    static const unsigned int UC_Nurse = 0;     /*!< Nurse have only read access */
    static const unsigned int UC_Doctor = 100;  /*!< Can edit patient info */
    static const unsigned int UC_Admin = 1000;  /*!< Can edit everything (Machines and users) */

private:

    QString m_name;             /*!< */
    unsigned int m_category;    /*!< */
    bool m_isOnline;            /*!< */

    bool m_isValid;             /*!< */

public:
    User():m_isValid(false) {}
    User(const QString& name, const unsigned int category, bool online)
        :m_name(name),m_category(category),m_isOnline(online) {}

    User(const User& user)
        :QObject(user.parent()),m_name(user.name()),m_category(user.category()),m_isOnline(user.isOnline()),m_isValid(user.isValid()) {}

    User& operator=(const User& user);

    const QString& name()const { return m_name; }
    unsigned int category()const { return m_category; }
    bool isOnline()const { return m_isOnline; }

    bool isValid()const { return m_isValid; }
};

/*! \class User User.h "Types/User.h"
    \brief User description (as from the database)
 */

/*! \fn User::User()
    \brief Creates an invalid user
 */

/*! \fn User::User(const QString& name, const unsigned int category, bool online)
    \brief Creates a user with the given information
    \param name the name of the new User
    \param category
    \param online
 */

/*! \fn User::User(const User& user)
    \brief
    \param user
 */

/*! \fn User& User :: operator=(const User& user)
    \brief
    \param user
    \return
*/

/*! \fn const QString& User :: name()const
    \brief
    \return the name
*/

/*! \fn unsigned int User :: category()const
    \brief
    \return the user category (or rights)
*/

/*! \fn bool User :: isOnline()const
    \brief Gets if the user is currently connected
    \return true if the user is connected
*/

/*! \fn bool User :: isValid()const
    \brief Gets if the current user is valid
    \return true if the user is valid
*/

#endif
