/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "MainScreenWidget.h"

#include <QVBoxLayout>

#include <QDeclarativeView>
#include <QDeclarativeContext>
#include <QDeclarativeListProperty>
#include <QVariantList>
#include <QDebug>

#include "QMLBarWidget.h"
#include "QMLPatientListWidget.h"
#include "QMLVersionningWidget.h"
#include "QMLEditDataWidget.h"
#include "QMLEditUsersWidget.h"
#include "QMLEditMachinesWidget.h"
#include "QMLChatWidget.h"

#include "Types/NameObject.h"
#include "Types/ButtonList.h"

#include "Types/Patient.h"
#include "Types/ListData.h"
#include "Types/PatientData.h"
#include "Types/OperationData.h"
#include "Types/VersionData.h"

#include <cassert>

QString MainScreenQMLWidget::PATIENT_LIST_WIDGET_NAME = QString("Patients list");
QString MainScreenQMLWidget::VERSIONNING_WIDGET_NAME = QString("Versionning");
QString MainScreenQMLWidget::EDITOR_WIDGET_NAME = QString("Edit data");
QString MainScreenQMLWidget::USERSEDITOR_WIDGET_NAME = QString("Edit user");
QString MainScreenQMLWidget::MACHINESEDITOR_WIDGET_NAME = QString("Edit machines");
QString MainScreenQMLWidget::CHAT_WIDGET_NAME = QString("Chat");

MainScreenQMLWidget :: MainScreenQMLWidget(QMap<QString, ModuleInterface*>* pPlugins, QWidget* parent)
    :QWidget(parent),m_pPlugins(pPlugins),m_pPatient(NULL)
{
    m_pLayout = new QVBoxLayout(this);

    m_pQMLBar = new QMLBarWidget();
    // m_pQMLBar->load("./data/qml/ButtonsBar.qml");
    m_pQMLBar->load("qrc:/qml/QMLBox/Sources/ButtonsBar.qml");
    connect(m_pQMLBar,SIGNAL(requestedTab(QString)),this,SLOT(changeTab(QString)));

    m_pPatientWidget = new QMLPatientListWidget();
    //m_pPatientWidget->load("./data/qml/MainScreen.qml");
    m_pPatientWidget->load("qrc:/qml/QMLBox/Sources/MainScreen.qml");
    connect(m_pPatientWidget,SIGNAL(requestPatient(QString)),this,SIGNAL(requestPatient(QString)));
    connect(m_pPatientWidget,SIGNAL(selectOperation(QString,QString)),this,SLOT(setOperation(QString,QString)));

    m_pVersionningWidget = new QMLVersionningWidget();
    // m_pVersionningWidget->load("./data/qml/VersionningScreen.qml");
    m_pVersionningWidget->load("qrc:/qml/QMLBox/Sources/VersionningScreen.qml");

    m_pEditorWidget = new QMLEditDataWidget();
    m_pEditorWidget->load("qrc:/qml/QMLBox/Sources/EditInformationScreen.qml");
    connect(m_pEditorWidget,SIGNAL(patientChanged()),this,SLOT(updatePatient()));

    m_pEditUserWidget = new QMLEditUsersWidget();
    m_pEditUserWidget->load("qrc:/qml/QMLBox/Sources/EditUsersScreen.qml");
    connect(m_pEditUserWidget,SIGNAL(userNew(QString, QString, QString)),this,SIGNAL(userNew(QString, QString, QString)));
    connect(m_pEditUserWidget,SIGNAL(userNameChanged(QString, QString)),this,SIGNAL(userNameChanged(QString,QString)));
    connect(m_pEditUserWidget,SIGNAL(userCategoryChanged(QString, QString)),this,SIGNAL(userCategoryChanged(QString,QString)));
    connect(m_pEditUserWidget,SIGNAL(deleteUser(QString)),this,SIGNAL(deleteUser(QString)));

    m_pEditMachinesWidget = new QMLEditMachinesWidget();
    m_pEditMachinesWidget->load("qrc:/qml/QMLBox/Sources/EditMachinesScreen.qml");
    connect(m_pEditMachinesWidget,SIGNAL(addMachine(QString, QString)),this,SIGNAL(addMachine(QString, QString)));
    connect(m_pEditMachinesWidget,SIGNAL(deleteMachine(QString)),this,SIGNAL(deleteMachine(QString)));

    m_pChatWidget = new QMLChatWidget();
    m_pChatWidget->load("qrc:/qml/QMLBox/Sources/ChatScreen.qml");
    connect(m_pChatWidget,SIGNAL(sendMessage(QString)),this,SIGNAL(sendMessage(QString)));

    m_pLayout->addWidget(m_pQMLBar);
    m_pLayout->addWidget(m_pPatientWidget);
    m_pLayout->setSizeConstraint(QLayout::SetNoConstraint);

    this->resize(1000,700);

    this->updateButtonsList();
}

MainScreenQMLWidget :: ~MainScreenQMLWidget()
{
    // To avoid this widget destructing the plugins, we redefine their parents to NULL
    // The widgets inside will be correctly deleted during the plugins deletion in MedCenter destructor
    foreach (ModuleInterface* pModule, *m_pPlugins)
    {
        pModule->getWidget()->setParent(NULL);
    }

    delete m_pQMLBar;
    delete m_pPatientWidget;
    delete m_pVersionningWidget;
    delete m_pEditorWidget;
    delete m_pEditUserWidget;
    delete m_pEditMachinesWidget;
    delete m_pChatWidget;

    delete m_pLayout;
}

void MainScreenQMLWidget :: setPatientNames(const QList<QString>& namesList)
{
    m_pPatientWidget->setPatientList(namesList);
}

void MainScreenQMLWidget :: setUsersList(const QList<User>& usersList)
{
    m_pEditUserWidget->setUsersList(usersList);
    m_pChatWidget->setUsersList(usersList);
}

void MainScreenQMLWidget :: setMachinesList(const QList<MachineData>& machinesList)
{
    m_pEditMachinesWidget->setMachineList(machinesList);
}

void MainScreenQMLWidget :: updateButtonsList()
{
    m_buttonList.clear();
    m_buttonList.add(PATIENT_LIST_WIDGET_NAME,QUrl("./data/list.png"));

    if ( m_pPatient )
    {
        m_buttonList.add(VERSIONNING_WIDGET_NAME,QUrl("./data/versionning.png"));
        if ( m_userCategory >= User::UC_Doctor )
        {
            m_buttonList.add(EDITOR_WIDGET_NAME,QUrl("./data/edit_data.png"));
        }

        foreach (ModuleInterface* pModule, *m_pPlugins)
        {
            if ( pModule->needDisplay() )
            {
                m_buttonList.add(pModule->name(),pModule->imageSource());
            }
        }
    }

    // Default buttons
    m_buttonList.add(CHAT_WIDGET_NAME,QUrl("./data/chat.png"));

    if ( m_userCategory >= User::UC_Admin )
    {
        m_buttonList.add(USERSEDITOR_WIDGET_NAME,QUrl("./data/edit_user.png"));
        m_buttonList.add(MACHINESEDITOR_WIDGET_NAME,QUrl("./data/edit_machine.png"));
    }

    m_pQMLBar->setButtons(m_buttonList.getList());
}

void MainScreenQMLWidget :: updateData()
{
    m_pPatientWidget->setPatient(m_pPatient);
    m_pEditorWidget->setPatient(m_pPatient);
}

void MainScreenQMLWidget :: setPatient(Patient* pPatient)
{
    assert(pPatient);

    m_pPatient = pPatient;
    ListData<OperationData>* pOperations = dynamic_cast<ListData<OperationData>*>(pPatient->get("Operations"));
    if ( pOperations->dataList().size() > 0 )
    {
        foreach (ModuleInterface* pModule, *m_pPlugins)
        {
            pModule->setPatientData(pPatient,pOperations->dataList()[0]->name());
        }
    }

    VersionData* pVersionData = dynamic_cast<VersionData*>(pPatient->get("VersionData"));
    if ( pVersionData )
    {
        m_pVersionningWidget->setVersionData(pVersionData);
    }

    this->updateButtonsList();
    this->updateData();
}

void MainScreenQMLWidget :: setOperation(QString operationName, QString operationDate)
{
    (void) operationDate;

    m_folder = operationName;
    foreach (ModuleInterface* pModule, *m_pPlugins)
    {
        pModule->setPatientData(m_pPatient,m_folder);
    }
}

void MainScreenQMLWidget :: constructPlugins()
{
    foreach (ModuleInterface* pModule, *m_pPlugins)
    {
        pModule->createGui();
    }
}

void MainScreenQMLWidget :: changeTab(QString tabName)
{
    if ( m_pLayout->itemAt(1) )
    {
        QWidget* pOldItem = m_pLayout->itemAt(1)->widget();
        if ( pOldItem )
        {
            pOldItem->hide();
            m_pLayout->removeWidget(pOldItem);
        }
    }

    if ( tabName == PATIENT_LIST_WIDGET_NAME )
    {
        m_pLayout->addWidget(m_pPatientWidget,Qt::AlignHCenter);
        m_pPatientWidget->show();
    }
    else if ( tabName == VERSIONNING_WIDGET_NAME )
    {
        m_pLayout->addWidget(m_pVersionningWidget,Qt::AlignHCenter);
        m_pVersionningWidget->show();
    }
    else if ( tabName == EDITOR_WIDGET_NAME )
    {
        m_pLayout->addWidget(m_pEditorWidget,Qt::AlignHCenter);
        m_pEditorWidget->show();
    }
    else if ( tabName == USERSEDITOR_WIDGET_NAME )
    {
        m_pLayout->addWidget(m_pEditUserWidget,Qt::AlignHCenter);
        m_pEditUserWidget->show();
    }
    else if ( tabName == MACHINESEDITOR_WIDGET_NAME )
    {
        m_pLayout->addWidget(m_pEditMachinesWidget,Qt::AlignHCenter);
        m_pEditMachinesWidget->show();
    }
    else if ( tabName == CHAT_WIDGET_NAME )
    {
        m_pLayout->addWidget(m_pChatWidget,Qt::AlignHCenter);
        m_pChatWidget->show();
    }
    else if ( m_pPlugins->contains(tabName) )
    {
        m_pLayout->addWidget((*m_pPlugins)[tabName]->getWidget(),Qt::AlignHCenter);
        (*m_pPlugins)[tabName]->getWidget()->show();
    }
    else
    {
        qDebug() << "Tab Name (" << tabName << ") not found";
    }
}

void MainScreenQMLWidget :: updatePatient()
{
    qDebug() << "Patient changed !";

    m_pVersionningWidget->updateData();
    emit patientChanged();
}

void MainScreenQMLWidget :: addMessage(QString message)
{
    m_pChatWidget->addMessage(message);
}
