#ifndef __QMLCHATWIDGET_H__
#define __QMLCHATWIDGET_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "QMLWidget.h"

#include "Types/User.h"

class QMLChatWidget : public QMLWidget
{
    Q_OBJECT

private:
    static const int MESSAGES_BUFFER_SIZE = 2048;       /*!< Number of messages shown */

    QList<QObject*> m_messageList;                      /*!< */
    QList<QObject*> m_users;                            /*!< */

    void deleteList();
    void updateUsersList();

protected:
    bool updateQML();

public:
    QMLChatWidget(QWidget* parent=0);
    ~QMLChatWidget();

    Q_SLOT void setUsersList(const QList<User>& namesList);

    Q_SLOT void addMessage(QString message);

    Q_SIGNAL void sendMessage(QString message);
};

/*! \class QMLChatWidget QMLChatWidget.h "UI/QMLChatWidget.h"
    \brief Interface to display a chat with a list of users
 */

/*! \fn QMLChatWidget::QMLChatWidget(QWidget* parent=0)
    \param parent
 */

/*! \fn QMLChatWidget::~QMLChatWidget()
 */

/*! \fn void QMLChatWidget::deleteList();
    \brief Delete the list of users shown
 */

/*! \fn void QMLChatWidget::setUsersList(const QList<User>& namesList);
    \brief Sets the list of users
    \param namesList
 */

/*! \fn void QMLChatWidget::addMessage(QString message);
    \brief Add a message in the chat
    \param message
 */

/*! \fn void QMLChatWidget::sendMessage(QString message);
    \brief Signal send when the user sends a new message
    \param message
 */

#endif
