#ifndef __QMLEDITDMACHINESWIDGET_H__
#define __QMLEDITDMACHINESWIDGET_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "QMLWidget.h"

#include "Network/Types/MachineData.h"

class QMLEditMachinesWidget : public QMLWidget
{
    Q_OBJECT

private:
    QList<QObject*> m_machines;     /*!< */

    void deleteList();
    void updateMachinesList();

protected:
    bool updateQML();

public:
    QMLEditMachinesWidget(QWidget* parent=0);
    ~QMLEditMachinesWidget();

    Q_SLOT void setMachineList(const QList<MachineData>& namesList);

    Q_SIGNAL void addMachine(QString machineIP, QString machineName);
    Q_SIGNAL void deleteMachine(QString machineIP);
};

/*! \class QMLEditMachinesWidget QMLEditMachinesWidget.h "UI/QMLEditMachinesWidget.h"
    \brief Interface to display and edit machines in a list
 */

/*! \fn QMLEditMachinesWidget::QMLEditMachinesWidget(QWidget* parent=0)
    \param parent
 */

/*! \fn QMLEditMachinesWidget::~QMLEditMachinesWidget()
 */

/*! \fn void QMLEditMachinesWidget::deleteList();
    \brief Delete the list of machines shown
 */

/*! \fn void QMLEditMachinesWidget::updateMachinesList()
    \brief Sends the list of machines to QML
 */

/*! \fn void QMLEditMachinesWidget::setMachineList(const QList<MachineData>& namesList);
    \brief Set the list of machines
    \param namesList
 */

/*! \fn void QMLEditMachinesWidget::addMachine(QString machineIP, QString machineName);
    \brief Signal send when a machine is added
    \param machineIP
    \param machineName
 */

/*! \fn void QMLEditMachinesWidget::deleteMachine(QString machineIP);
    \brief Signal send when a machine should be removed
    \param machineIP
 */

#endif
