#ifndef __QMLEDITUSERSWIDGET_H__
#define __QMLEDITUSERSWIDGET_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "QMLWidget.h"

#include "Types/User.h"

class QMLEditUsersWidget : public QMLWidget
{
    Q_OBJECT

private:
    QList<QObject*> m_users;    /*!< */

    void deleteList();
    void updateUsersList();

protected:
    bool updateQML();

public:
    QMLEditUsersWidget(QWidget* parent=0);
    ~QMLEditUsersWidget();

    Q_SLOT void setUsersList(const QList<User>& namesList);

    Q_SIGNAL void userNew(QString name, QString password, QString category);
    Q_SIGNAL void deleteUser(QString userName);

    Q_SIGNAL void userNameChanged(QString oldName, QString newName);
    Q_SIGNAL void userCategoryChanged(QString name, QString newCategory);
};

/*! \class QMLEditUsersWidget QMLEditUsersWidget.h "UI/QMLEditUsersWidget.h"
    \brief Interface to display and edit user informations
 */

/*! \fn QMLEditUsersWidget::QMLEditUsersWidget(QWidget* parent=0)
    \param parent
 */

/*! \fn QMLEditUsersWidget::~QMLEditUsersWidget()
 */

/*! \fn void QMLEditUsersWidget::deleteList();
    \brief Delete the list of users shown
 */

/*! \fn void QMLEditUsersWidget::updateUsersList()
    \brief Sends the list of users to QML
 */

/*! \fn void QMLEditUsersWidget::setUsersList(const QList<User>& namesList);
    \brief Sets the user list
    \param namesList
 */

/*! \fn void QMLEditUsersWidget::userNew(QString name, QString password, QString category);
    \brief Signal send when a new user is requested
    \param name
    \param password
    \param category
 */

/*! \fn void QMLEditUsersWidget::deleteUser(QString userName);
    \brief Signal send when a user must be deleted
    \param userName
 */

/*! \fn void QMLEditUsersWidget::userNameChanged(QString oldName, QString newName);
    \brief Signal send when a user name changed
    \param oldName
    \param newName
 */

/*! \fn void QMLEditUsersWidget::userCategoryChanged(QString name, QString newCategory);
    \brief Signal send when a category of a user changed
    \param name
    \param newCategory
 */

#endif
