/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "QMLPatientListWidget.h"

#include <QDeclarativeView>
#include <QDeclarativeContext>

#include "Types/NameObject.h"

#include "Types/Patient.h"
#include "Types/ListData.h"
#include "Types/PatientData.h"
#include "Types/OperationData.h"

#include <cassert>

QMLPatientListWidget :: QMLPatientListWidget(QWidget *parent)
    :QMLWidget(parent)
{
    // this->resize(1000,400);
}

QMLPatientListWidget :: ~QMLPatientListWidget()
{
    this->deleteList();
}

void QMLPatientListWidget :: deleteList()
{
    foreach(QObject* pObject, m_pPatientNames)
    {
        delete pObject;
    }

    m_pPatientNames.clear();
}

void QMLPatientListWidget :: updatePatientList()
{
    m_pView->rootContext()->setContextProperty("patientNames", QVariant::fromValue(m_pPatientNames));
}

bool QMLPatientListWidget :: updateQML()
{
    bool bResult = true;

    bResult &= connect(m_pQMLObject,SIGNAL(selectedItem(QString)),this,SIGNAL(requestPatient(QString)));
    bResult &= connect(m_pQMLObject,SIGNAL(operationSelected(QString,QString)),this,SIGNAL(selectOperation(QString,QString)));

    return bResult;
}

void QMLPatientListWidget :: setPatientList(const QList<QString>& namesList)
{
    this->deleteList();

    foreach(QString name, namesList)
    {
        m_pPatientNames.append(new NameObject(name));
    }

    this->updatePatientList();
}

void QMLPatientListWidget :: setPatient(const Patient* pPatient)
{
    assert(pPatient);

    PatientData* pPatientData = dynamic_cast<PatientData*>(pPatient->get("PatientData"));
    if ( pPatientData )
    {
        QList<QObject*> tmpList;
        QObject* pObject = dynamic_cast<QObject*>(pPatientData);
        tmpList.append(pObject);
        m_pView->rootContext()->setContextProperty("patientData", QVariant::fromValue(tmpList));
    }

    ListData<OperationData>* pListOperations = dynamic_cast<ListData<OperationData> *>(pPatient->get("Operations"));
    if ( pListOperations )
    {
        QList<QObject*> tmpList;
        foreach (OperationData* pOperation, pListOperations->dataList())
        {
            tmpList.append(pOperation);
        }
        m_pView->rootContext()->setContextProperty("patientOperationData", QVariant::fromValue(tmpList));
    }
}
