#ifndef __QMLPATIENTLISTWIDGET_H__
#define __QMLPATIENTLISTWIDGET_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "QMLWidget.h"

#include <QDate>

class Patient;

class QMLPatientListWidget : public QMLWidget
{
    Q_OBJECT

private:
    QList<QObject*> m_pPatientNames;    /*!< */

    void deleteList();
    void updatePatientList();

protected:
    bool updateQML();

public:
    QMLPatientListWidget(QWidget* parent=0);
    ~QMLPatientListWidget();

    Q_SLOT void setPatientList(const QList<QString>& namesList);
    Q_SLOT void setPatient(const Patient* pPatient);

    Q_SIGNAL void requestPatient(QString patientName);
    Q_SIGNAL void selectOperation(QString operationName, QString operationDate);
};

/*! \class QMLPatientListWidget QMLPatientListWidget.h "UI/QMLPatientListWidget.h"
    \brief Interface to display patient in a list
 */

/*! \fn QMLPatientListWidget::QMLPatientListWidget(QWidget* parent=0)
    \param parent
 */

/*! \fn QMLPatientListWidget::~QMLPatientListWidget()
 */

/*! \fn void QMLPatientListWidget::deleteList();
    \brief Delete the list of Patient shown
 */

/*! \fn void QMLPatientListWidget::updatePatientList()
    \brief Sends the list of patient to QML
 */

/*! \fn void QMLPatientListWidget::setPatientList(const QList<QString>& namesList);
    \brief Sets the list of patients to show
    \param namesList the list of names
 */

/*! \fn void QMLPatientListWidget::setPatient(const Patient* pPatient);
    \brief Sets the patient information to show
    \param pPatient
 */

/*! \fn void QMLPatientListWidget::requestPatient(QString patientName);
    \brief Signal send when a patient is selected
    \param patientName the name of the patien selected
 */

/*! \fn void QMLPatientListWidget::selectOperation(QString operationName, QString operationDate);
    \brief Signal send when an operation is selected
    \param operationName
    \param operationDate
 */

#endif
