#ifndef __BUTTONLIST_H__
#define __BUTTONLIST_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QList>
#include <QObject>

#include "ButtonObject.h"

class ButtonList
{
private:
    QList<QObject*> m_buttons;  /*!< */

public:
    ButtonList() {}
    ~ButtonList();

    void add(ButtonObject* pButton);
    void add(const QString& title, const QUrl& source);
    void clear();

    const QList<QObject*> getList()const { return m_buttons; }
};

/*! \class ButtonList ButtonList.h "UI/Types/ButtonList.h"
    \brief List of ButtonObject
 */

/*! \fn ButtonList::ButtonList()
 */

/*! \fn ButtonList::~ButtonList()
    Clear the list and deletes the buttons contained
    \sa clear()
 */

/*! \fn void ButtonList::add(ButtonObject* pButton)
    \brief Adds a button in the list
    \param pButton pointer on the new button
 */

/*! \fn void ButtonList::add(const QString& title, const QUrl& source)
    \brief Adds a new button constructs from the <a>title</a> and <a>source</a>
    \param title
    \param source source of the image to display with the button
*/

/*! \fn void ButtonList::clear()
    \brief Removes and delete all buttons in the list
 */

/*! \fn const QList<QObject*> ButtonList::getList()const
    \brief Gets the list of buttons (as QObjects) ready to be send to QML
    \return
 */


#endif
