#ifndef __BUTTONOBJECT_H__
#define __BUTTONOBJECT_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QObject>

#include <QString>
#include <QUrl>

class ButtonObject : public QObject
{
    Q_OBJECT

    Q_PROPERTY(QString name READ name CONSTANT)
    Q_PROPERTY(QUrl image READ source CONSTANT) /*!< */

private:

    QString m_name; /*!< */
    QUrl m_source;  /*!< */

public:
    ButtonObject(const QString& name, const QUrl& source, QObject* parent=0)
        :QObject(parent),m_name(name),m_source(source) {}

    const QString& name()const { return m_name; }
    const QUrl& source()const { return m_source; }

    Q_SIGNAL void titleChanged();
    Q_SIGNAL void sourceChanged();
};

/*! \class ButtonObject ButtonObject.h "UI/Types/ButtonObject.h"
    \brief Button type to be sent to QML
*/

/*! \fn ButtonObject::ButtonObject(const QString& name, const QUrl& source, QObject* parent=0)
    \param name
    \param source
    \param parent
*/

/*! \fn const QString& ButtonObject::name()const
    \brief returns the name
    \return
 */

/*! \fn const QUrl& ButtonObject::source()const
    \brief returns the path to the source of the picture
    \return
 */

/*! \fn void ButtonObject::titleChanged()
    \brief Sent when the title changed
 */

/*! \fn void ButtonObject::sourceChanged()
    \brief Sent when the source changed
 */

#endif
