/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "ByteArrayUtils.h"

#include <QByteArray>
#include <QString>
#include <QDate>
#include <QDebug>

#include <cassert>

QString ByteArrayUtils::readString(const QByteArray& data, int index, int* pNbRead)
{
    int nameLength = data.indexOf('\0',index)-index;
    QByteArray nameData = data.mid(index,nameLength);

    if ( pNbRead )
    {
        *pNbRead = nameLength+1;
    }

    return QString(nameData);
}

int ByteArrayUtils::readNumber(const QByteArray& data, int index, int* pNbRead)
{
    int localNbRead = 0;
    bool isOk = true;
    QString dateString = ByteArrayUtils::readString(data,index,&localNbRead);
    if ( localNbRead == -1 )
    {
        if ( pNbRead )
        {
            *pNbRead = -1;
        }
        return -1;
    }

    int dataShort = dateString.toInt(&isOk);
    if ( pNbRead )
    {
        if ( isOk != true )
        {
            *pNbRead = -1;
        }
        else
        {
            *pNbRead = localNbRead;
        }
    }

    return dataShort;
}

QDate ByteArrayUtils::readDate(const QByteArray& data, int index, int* pNbRead)
{
    int localNbRead = 0;
    QString dateString = ByteArrayUtils::readString(data,index,&localNbRead);
    if ( localNbRead == -1 )
    {
        if ( pNbRead )
        {
            *pNbRead = -1;
        }
        return QDate();
    }

    QDate dateData = QDate::fromString(dateString);
    if ( pNbRead )
    {
        if ( !dateData.isValid() )
        {
            *pNbRead = -1;
        }
        else
        {
            *pNbRead = localNbRead;
        }
    }

    return dateData;
}

QDateTime ByteArrayUtils :: readDateTime(const QByteArray& data, int index, int* pNbRead)
{
    int localNbRead = 0;
    QString dateString = ByteArrayUtils::readString(data,index,&localNbRead);
    if ( localNbRead == -1 )
    {
        if ( pNbRead )
        {
            *pNbRead = -1;
        }
        return QDateTime();
    }

    QDateTime dateTimeData = QDateTime::fromString(dateString);
    if ( pNbRead )
    {
        if ( !dateTimeData.isValid() )
        {
            *pNbRead = -1;
        }
        else
        {
            *pNbRead = localNbRead;
        }
    }

    return dateTimeData;
}

QByteArray ByteArrayUtils::readData(const QByteArray& data, int index, int* pNbRead)
{
    int localNbRead = 0;
    int dataSize = ByteArrayUtils::readNumber(data,index,&localNbRead);
    if ( localNbRead == -1 )
    {
        if ( pNbRead )
        {
            *pNbRead = -1;
        }
        return QByteArray();
    }

    if ( dataSize > data.size() )
    {
        qWarning() << "The size of the data to read is bigger than the data available (data size: " << data.size() << ")";
        if ( pNbRead )
        {
            *pNbRead = -1;
        }
        return QByteArray();
    }

    QByteArray dataData = data.mid(index+localNbRead,dataSize);
    if ( pNbRead )
    {
        *pNbRead = localNbRead + dataSize;
    }
    return dataData;
}

void ByteArrayUtils::writeString(QByteArray& data, const QString& stringData)
{
    data.append(stringData);
    data.append('\0'); // Make sure the string is null terminated
}

void ByteArrayUtils::writeDate(QByteArray& data, const QDate& dateData)
{
    ByteArrayUtils::writeString(data,dateData.toString());
}

void ByteArrayUtils :: writeDateTime(QByteArray& data, const QDateTime& dateTimeData)
{
    ByteArrayUtils::writeString(data,dateTimeData.toString());
}

void ByteArrayUtils::writeData(QByteArray& data, const QByteArray& dataData)
{
    ByteArrayUtils::writeNumber<int>(data,dataData.size());
    data.append(dataData);
}
