#ifndef __BYTEARRAYUTILS_H__
#define __BYTEARRAYUTILS_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

class QByteArray;
#include <QString>
#include <QDate>
#include <QDateTime>

class ByteArrayUtils
{
public:
    static QString readString(const QByteArray& data, int index=0, int* pNbRead=NULL);
    static QDate readDate(const QByteArray& data, int index=0, int* pNbRead=NULL);
    static QDateTime readDateTime(const QByteArray& data, int index=0, int* pNbRead=NULL);
    static QByteArray readData(const QByteArray& data, int index=0, int* pNbRead=NULL);

    static int readNumber(const QByteArray& data, int index=0, int* pNbRead=NULL);

    static void writeString(QByteArray& data, const QString& stringData);
    static void writeDate(QByteArray& data, const QDate& dateData);
    static void writeDateTime(QByteArray& data, const QDateTime& dateTimeData);
    static void writeData(QByteArray& data, const QByteArray& dataData);

    template <typename T>
    static void writeNumber(QByteArray& data, const T numberData)
    {
        ByteArrayUtils::writeString(data,QString::number(numberData));
    }

};

/*! \class ByteArrayUtils ByteArrayUtils.h "Utils/ByteArrayUtils.h"
    \brief Utility class to give easy functoins to add / read data with QByteArray (in such way that they are usable on Network)
*/

/*! \fn static QString ByteArrayUtils::readString(const QByteArray& data, int index=0, int* pNbRead=NULL)
    \brief Reads a string (finished by 0) from <a>data</a>
    \param data the source of the data
    \param index the index where to read
    \param pNbRead if not NULL, will containt the number of the byte read
    \return the QString read
 */

/*! \fn static QDate ByteArrayUtils::readDate(const QByteArray& data, int index=0, int* pNbRead=NULL)
    \brief Reads a date from <a>data</a>
    \param data the source of the data
    \param index the index where to read
    \param pNbRead if not NULL, will containt the number of the byte read
    \return the QDate read
 */

/*! \fn static QDateTime ByteArrayUtils::readDateTime(const QByteArray& data, int index=0, int* pNbRead=NULL)
    \brief Reads a date time from <a>data</a>
    \param data the source of the data
    \param index the index where to read
    \param pNbRead if not NULL, will containt the number of the byte read
    \return the QDateTime read
 */

/*! \fn static QByteArray ByteArrayUtils::readData(const QByteArray& data, int index=0, int* pNbRead=NULL)
    \brief Reads data (the size is first read, then the data itself) from <a>data</a>
    \param data the source of the data
    \param index the index where to read
    \param pNbRead if not NULL, will containt the number of the byte read
    \return the QByteArray read
 */

/*! \fn static int ByteArrayUtils::readNumber(const QByteArray& data, int index=0, int* pNbRead=NULL)
    \brief Reads a number from <a>data</a>
    \param data the source of the data
    \param index the index where to read
    \param pNbRead if not NULL, will containt the number of the byte read
    \return the number read
 */

/*! \fn static void ByteArrayUtils::writeString(QByteArray& data, const QString& stringData)
    \brief Write a string in <a>data</a>
    \param data the array where to write
    \param stringData the string to write
 */

/*! \fn static void ByteArrayUtils::writeDate(QByteArray& data, const QDate& dateData)
    \brief Write a data in <a>data</a>
    \param data the array where to write
    \param dateData the date to write
 */

/*! \fn static void ByteArrayUtils::writeDateTime(QByteArray& data, const QDateTime& dateTimeData)
    \brief Write a date time in <a>data</a>
    \param data the array where to write
    \param dateTimeData the date time to write
 */

/*! \fn static void ByteArrayUtils::writeData(QByteArray& data, const QByteArray& dataData)
    \brief Write some data in <a>data</a>
    \param data the array where to write
    \param dataData the data to write
 */

/*! \fn static void ByteArrayUtils::writeNumber(QByteArray& data, const T numberData)
    \brief Write a number in <a>data</a>
    \param data the array where to write
    \param numberData the number to write
 */

#endif
