#ifndef __MED_DATABASE__HPP__
#define __MED_DATABASE__HPP__

/*
 * "MedCenter" is an interactive application for hospitals.
 *
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QtSql>

#include "Types/Patient.h"
#include "Types/FileData.h"
#include "Types/User.h"

class OperationData;

class MedDatabase
{
public:


private:
        MedDatabase(QObject* objectParent);
        MedDatabase(const MedDatabase&);
        MedDatabase& operator=(const MedDatabase&);
        ~MedDatabase();

        static const int UserConnected;
        static const int UserDisconnected;

public:
        static bool initDatabase();
        static void closeDatabase();
        static QSqlError lastError();

        static bool populate();

        static const QList< User > listUsers();
        static bool connectUser(QString nameUser, QString passwordUser);
        static bool disconnectUser(QString nameUser);
        static User user(QString nameUser);

        static void addUser(const QString& name, const QString& password, const QString& category);
        static void deleteUser(const QString& name);
        static void changeUserName(const QString& oldName, const QString& newName);
        static void changeUserCategory(const QString& name, const QString& newCategory);

        //static const QList< Patient > listPatients();
        const QList<SimplePatient> listPatients();
        static bool setPatient(const Patient* pPatient);
        static Patient* patient(int idPatient);

        static bool addItem(int idPatient, const FileData& fileData);
        FileData* item(int idItem);
        QList<FileData*> getPatientItems(int idPatient);
        static bool setItem(int idItem, int idPatient, QString type, QString value);

        QList<OperationData* > getPatientOperations(int idPatient);
        bool setOperation(const OperationData& operation, int patientId);
};

/** - Documentation -
  *
  * \class MedDatabase
  *  \brief ...
  *
  * \fn ...
  *  \brief ...
  *
  * \fn ...
  *  \brief ...
  *
  */

#endif // MED_DATABASE__HPP
