#ifndef __RADIO_H__
#define __RADIO_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QString>
#include <QPixmap>

class Radio
{
private:

    QString m_name;     /*!< */
    QPixmap m_radio;    /*!< */

public:
    static Radio load(const QString& fileName);
    static Radio load(const QString& name, const QByteArray& data);

    const QString& name()const { return m_name; }
    const QPixmap& radio()const { return m_radio; }
};

/*! \class Radio Radio.h "Radio.h"
 *  \brief Data for the radio
 *  A radio is defined by a name
 */

/*! \fn static Radio Radio::load(const QString& fileName)
 *  \brief Load a radio from a file
 *  \param fileName the name of the file to load
 *  \return the newly loaded radio
 *  \sa Radio::load(const QString& name, const QByteArray& data)
 */

/*! \fn static Radio Radio::load(const QString& name, const QByteArray& data)
 *  \brief Load a radio from a QByteArray
 *  \param name the name of the radio
 *  \param data the data of the radio to load
 *  \return the newly loaded radio
 *  \sa Radio::load(const QString& fileName)
 */

/*! \fn const QString& Radio::name()const
 *  \brief Get the name of the radio
 *  \return the name
 */

/*! \fn const QPixmap& Radio::radio()const
 *  \brief Get the radio
 *  \return
 */

#endif
