#ifndef __RADIOVIEWERWIDGET_H__
#define __RADIOVIEWERWIDGET_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QWidget>
#include <QPoint>

class RadioMap;

class RadioScrollAreaWidget;
class QLabel;

class Logger;

class RadioViewerWidget : public QWidget
{
    Q_OBJECT

private:
    RadioMap* m_pRadioMap;                  /*!< */

    RadioScrollAreaWidget* m_pScrollArea;   /*!< */

    float m_zoom;               /*!< Zoom ratio */
    QPoint m_radioSelection;    /*!< Radio selected */

    Logger* m_pLogger;

protected:

    void resizeEvent(QResizeEvent* pResizeEvent);
    // void wheelEvent(QWheelEvent* pWheelEvent);

    void mouseDoubleClickEvent(QMouseEvent* pMouseEvent);
    void keyPressEvent(QKeyEvent* pKeyEvent);

    void paintEvent(QPaintEvent* pPaintEvent);

public:
    explicit RadioViewerWidget(Logger* pLogger, QWidget* parent=0);
    ~RadioViewerWidget();

    void update();

    Q_SLOT void clearData();

    Q_SLOT void loadRadioFile(const QString& name, const QByteArray& file);
    Q_SLOT void loadRadioFiles();
};

/*! \class RadioViewerWidget RadioViewerWidget.h "RadioViewerWidget.h"
 *  \brief Widget to display radios, handling zooming and more detailed radio selection
 */

/*! \fn void RadioViewerWidget :: resizeEvent(QResizeEvent* pResizeEvent)
    \brief Handle the resize events
    \param pResizeEvent the information on new size of the window
 */

/*! \fn void RadioViewerWidget :: mouseDoubleClickEvent(QMouseEvent* pMouseEvent)
    \brief Handle the double click events
    \param pMouseEvent the information on mouse
 */

/*! \fn void RadioViewerWidget :: keyPressEvent(QKeyEvent* pKeyEvent)
    \brief Handle the keyboard events
    \param pKeyEvent the information on keyboard
 */

/*! \fn void RadioViewerWidget :: paintEvent(QPaintEvent* pPaintEvent)
    \brief Handle the paint event
    \param pPaintEvent the information on painting
 */

/*! \fn explicit RadioViewerWidget::RadioViewerWidget(Logger* pLogger, QWidget* parent=0)
 *  \param pLogger logger to use
 *  \param parent the parent of this widget
 */

/*! \fn RadioViewerWidget::~RadioViewerWidget()
 */

/*! \fn void RadioViewerWidget::update()
 *  \brief updates the widget to display a new radio / new zoom level
 */

/*! \fn void RadioViewerWidget::clearData()
    \brief Remove all radio previously loaded
 */

/*! \fn void RadioViewerWidget::loadRadioFile(const QString& name, const QByteArray& file)
    \brief Load radio from QByteArray
    \param name the name of the radio
    \param file the data to load
 */

/*! \fn void RadioViewerWidget::loadRadioFiles()
    \brief Load radio for an file selector
 */

#endif
