/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "ScanAnimation.h"

#include <cassert>

#include "ScanList.h"

ScanAnimation :: ScanAnimation(ScanList* pList, QObject* pObject)
    :QObject(pObject),m_pList(pList),m_currentImage(0),m_animationStep(125),m_running(true)
{
    assert(pList);

    connect(&m_animationTimer,SIGNAL(timeout()),this,SLOT(update()));
    m_animationTimer.start(m_animationStep);
}

void ScanAnimation :: update()
{
    m_currentImage++;
    m_animationTimer.start(m_animationStep);
    Q_EMIT changed();
}

void ScanAnimation :: setAnimationStep(unsigned int newAnimationStep)
{
    m_animationStep = newAnimationStep;
    m_animationTimer.start(m_animationStep);
}

void ScanAnimation :: setScanList(ScanList* pList)
{
    assert(pList);

    m_pList = pList;
}

void ScanAnimation :: nextScan()
{
    m_currentImage++;
    Q_EMIT changed();
}

void ScanAnimation :: previousScan()
{
    m_currentImage--;
    Q_EMIT changed();
}

void ScanAnimation :: setRunning(bool running)
{
    m_running = running;
    if ( m_running )
    {
        m_animationTimer.start(m_animationStep);
    }
    else
    {
        m_animationTimer.stop();
    }
}

const QPixmap& ScanAnimation :: getScan()const
{
    return m_pList->getScan(m_currentImage);
}
