#ifndef __SCANANIMATION_H__
#define __SCANANIMATION_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QObject>
#include <QTimer>

class ScanList;

class QPixmap;

class ScanAnimation : public QObject
{
    Q_OBJECT

private:

    ScanList* m_pList;              /*!< Pointer to the list of scan to animate */

    QTimer m_animationTimer;        /*!< Timer to change the scan (do the animation) */
    int m_currentImage;             /*!< Index of the current image */
    unsigned int m_animationStep;   /*!< Animation delay */

    bool m_running;                 /*!< true if the animation is running */

protected:

    Q_SLOT void update();

public:
    ScanAnimation(ScanList* pList, QObject* pObject = 0);

    unsigned int animationStep()const { return m_animationStep; }
    void setAnimationStep(unsigned int newAnimationStep);

    ScanList* scanList()const { return m_pList; }
    void setScanList(ScanList* pList);

    void nextScan();
    void previousScan();

    bool isRunning() { return m_running; }
    void setRunning(bool running);

    const QPixmap& getScan()const;

    Q_SIGNAL void changed();
};

/*! \class ScanAnimation ScanAnimation.h "ScanAnimation.h"
 *  \brief Animate a ScanList
 */

/*! \fn void ScanAnimation::update()
    \brief Update the animation (change the frame if the interval time is ellapsed)
 */

/*! \fn ScanAnimation::ScanAnimation(ScanList* pList, QObject* pObject = 0)
 *  \param pList a pointer to the list of scan to use
 *  \param pObject a pointer to the parent
 */

/*! \fn unsigned int ScanAnimation::animationStep()const
 *  \brief get the delay between two scans
 *  \return the delay between two scans
 */

/*! \fn void ScanAnimation::setAnimationStep(unsigned int newAnimationStep)
 *  \brief Set the delay between two scans
 *  \param newAnimationStep the new delay
 */

/*! \fn ScanList* ScanAnimation::scanList()const
 *  \brief Get the list of scans used in this animation
 *  \return a pointer to the list of scans
 */

/*! \fn void ScanAnimation::setScanList(ScanList* pList)
 *  \brief Set a new list of scans
 *  \param pList a pointer to the new list of scans
 */

/*! \fn void ScanAnimation::nextScan()
 *  \brief Pass to the next Scan
 */

/*! \fn void ScanAnimation::previousScan()
 *  \brief Pass to the previous Scan
 */

/*! \fn bool ScanAnimation::isRunning()
 *  \brief Get if the animation is running (not paused)
 *  \return true if the animation is running
 */

/*! \fn void ScanAnimation::setRunning(bool running)
 *  \brief Set if the animation is running (or paused)
 *  \param running true if the animation should run
 */

/*! \fn const QPixmap& ScanAnimation::getScan()const
 *  \brief Get the current scan
 *  \return the current scan image
 */

/*! \fn void ScanAnimation::changed()
    \brief Signal sent when the ScanAnimation changed (e.g. next frame)
 */

#endif
