/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include "ScanList.h"

#include <QDebug>



bool ScanList :: isExisting(const QString& name)
{
    // Checks if this has been already loaded
    foreach (Scan s, m_scans)
    {
        if ( s.name() == name )
        {
            return true;
        }
    }

    return false;
}

bool ScanList :: loadImage(const QString& fileName)
{
    if ( isExisting(fileName) )
    {
        // Already loaded, returning true since it's not an error
        return true;
    }

    Scan newScan = Scan::load(fileName);
    if ( newScan.scanPixmap().isNull())
    {
        qDebug() << "Fail to load scan '" << fileName << "'";
        return false;
    }

    m_scans.append(newScan);

    return true;
}

bool ScanList :: loadImage(const QString& scanName, const QByteArray& data)
{
    if ( isExisting(scanName) )
    {
        // Already loaded, returning true since it's not an error
        return true;
    }

    Scan newScan = Scan::load(scanName,data);
    if ( newScan.scanPixmap().isNull())
    {
        qDebug() << "Fail to load scan '" << scanName << "'";
        return false;
    }

    m_scans.append(newScan);

    return true;
}

const QPixmap& ScanList :: getScan(unsigned int i)const
{
    if ( m_scans.size() == 0 )
    {
        return m_invalidPixmap;
    }

    return m_scans.at(i % m_scans.size()).scanPixmap();
}

