#ifndef __SCANVIEWERWIDGET_H__
#define __SCANVIEWERWIDGET_H__

/*
 * Copyright 2011
 * 'MedCenter' is an interactive application for hospitals.
 * (c) Copyright 2011 - Abdelhafid Hafidi  <std.abdel[at]gmail.com>
 *                    - Alexandre Laurent  <lw.demoscene[at]gmail.com>
 *
 * [GPL]
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

#include <QWidget>

class QLabel;

class ScanList;
class ScanAnimation;

class Logger;

class ScanViewerWidget : public QWidget
{
    Q_OBJECT

private:

    ScanList* m_pScanList;              /*!< */
    ScanAnimation* m_pScanAnimation;    /*!< */

    QLabel* m_pDisplayLabel;            /*!< Widget to display the current pixmap */

    Logger* m_pLogger;

protected:

    void keyPressEvent(QKeyEvent* pKeyEvent);

public:
    explicit ScanViewerWidget(Logger* pLogger, QWidget* parent=0);
    ~ScanViewerWidget();

    Q_SLOT void clearData();
    Q_SLOT void loadScanFile(const QString& name, const QByteArray& file);
    Q_SLOT void loadScanFiles();

    Q_SLOT void redraw();
};

/*! \class ScanViewerWidget ScanViewerWidget.h "ScanViewerWidget.h"
 *  \brief Qt widget to display ScanAnimation from the ScanList
 */

/*! \fn void ScanViewerWidget::keyPressEvent(QKeyEvent* pKeyEvent)
    \brief Handles the keyboard events
    \param pKeyEvent information on the keyboard
 */

/*! \fn explicit ScanViewerWidget::ScanViewerWidget(Logger* pLogger, QWidget* parent=0)
    \param pLogger the logger to use
 *  \param parent the pointer to the parent
 */

/*! \fn ScanViewerWidget::~ScanViewerWidget()
 */

/*! \fn void ScanViewerWidget::clearData()
    \brief Clears all the data previously loaded
 */

/*! \fn void ScanViewerWidget::loadScanFile(const QString& name, const QByteArray& file)
    \brief Load a scan from a QByteArray
    \param name the name of the new scan
    \param file the data to load
 */

/*! \fn void ScanViewerWidget::loadScanFiles()
    \brief Load scans from a file selector
 */

/*! \fn void ScanViewerWidget::redraw()
    \brief Redraw the widget to change the scan displayed
 */

#endif
